%% PROVIDE_FACTOR_LABELS : Function for obtaining factor labels provided by the user
% Applied in the Scoring Utility of Psychological Test Toolbox
%

function varargout = Provide_factor_labels(varargin)

if nargin == 0  % LAUNCH GUI
    
    data=getappdata(0,'data');
    
    [f1,f2]=size(data.Pc);
    r_c=f2;
    
    finestra.N2=240;
    finestra.M2=130+35*r_c;
    pantalla=get(0,'ScreenSize');
    finestra.coordenades=[(pantalla(3)/2)-(finestra.N2/2)  (pantalla(4)/2)-(finestra.M2/2) finestra.N2 finestra.M2];
    handles.figlab = figure('Units','Pixels',...
    'color' , [0.941 0.941 0.941],...
    'Position',finestra.coordenades);
    set(handles.figlab, 'MenuBar','none','Name','Psychological Test Toolbox: Corrector Utility','Toolbar','none','NumberTitle','off','resize','off');

    handles.text_participants_labels1= uicontrol(handles.figlab,'Style','text',...
    'Units','pixels',...
    'position',[10 finestra.M2-20 240 20],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'HorizontalAlignment','left',...
    'BackgroundColor', [.941 .941 .941],...
    'String','Provide specific labels for');

    handles.text_participants_labels2= uicontrol(handles.figlab,'Style','text',...
    'Units','pixels',...
    'position',[10 finestra.M2-40 240 20],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'HorizontalAlignment','left',...
    'BackgroundColor', [.941 .941 .941],...
    'String','each content factor (up to');

    handles.text_participants_labels3= uicontrol(handles.figlab,'Style','text',...
    'Units','pixels',...
    'position',[10 finestra.M2-60 240 20],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'HorizontalAlignment','left',...
    'BackgroundColor', [.941 .941 .941],...
    'String','5 characters per label)');

    
    
    handles.buff_text={};
    handles.buff_edit={};
    
    for i=1:r_c
        buff=sprintf('Factor %.f',i);    
        altura=finestra.M2-70-i*35;
        
         handles.buff_text{i}= uicontrol(handles.figlab,'Style','text',...
        'Units','pixels',...
        'position',[10 altura 120 25],...
        'FontSize',14,...
        'fontname',char(data.font),...
        'HorizontalAlignment','left',...
        'BackgroundColor', [.941 .941 .941],...
        'String',buff);
        
        handles.buff_edit{i}= uicontrol(handles.figlab,'Style','edit',...
        'Units','pixels',...
        'position',[110 altura 120 25],...
        'FontSize',13,...
        'fontname',char(data.font),...
        'HorizontalAlignment','left',...
        'BackgroundColor', [.941 .941 .941],...
        'String','');
    end;
    
    %CANCEL button
    handles.cancel= uicontrol(handles.figlab,'Style','Pushbutton',...
        'Units','pixels',...
        'position',[10 10 100 35],...
        'Fontname',char(data.font),...
        'Fontsize',13,...
        'ForegroundColor',[.2 .2 .2],...
        'BackgroundColor',[.911 .911 .911],...
        'String','Cancel');

    %OK button
    handles.ok= uicontrol(handles.figlab,'Style','Pushbutton',...
        'Units','pixels',...
        'position',[130 10 100 35],...
        'Fontname',char(data.font),...
        'Fontsize',13,...
        'ForegroundColor',[.2 .2 .2],...
        'BackgroundColor',[.911 .911 .911],...
        'String','OK');
    
    set(handles.cancel,...
        'Callback',{@Cancel_Callback});
    set(handles.ok,...
        'Callback',{@Ok_Callback, handles});
    
    if nargout > 0
            varargout{1} = handles.figlab;
    end

elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

    try
        if (nargout)
            [varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
        else
            feval(varargin{:}); % FEVAL switchyard
        end
    catch
        disp(lasterr);
    end

end

function varargout = Cancel_Callback (gcf,event_data,handles,varargin)
    
    data=getappdata(0,'data');
    if isfield(data,'factor_labels')
        data = rmfield(data,'factor_labels');
    end
    setappdata(0,'data',data);

    delete(gcbf);

return;

function varargout = Ok_Callback (gcbf,event_data,handles,varargin)

    data=getappdata(0,'data');
    data.factor_labels={};
    
    [f1,f2]=size(data.Pc);
    r_c=f2;
    
    for i=1:r_c
        buff_label=get(handles.buff_edit{i},'string');
        [f1,f2]=size(buff_label);
        
        if f2==0
            buff=sprintf('The label corresponding to Factor %.f is empty.',i);
            errordlg(buff,'Psychological Test Toolbox: Corrector Utility');
            return;
        end;
        
        if f2<6 %no problem
            data.factor_labels{i}=buff_label;
        else
            buff=sprintf('The label provided for Factor %.f is too long (5 characters max)',i);
            errordlg(buff,'Psychological Test Toolbox: Corrector Utility');
            return;
        end;     
    end;
    
    %SAVE DATA 
    setappdata(0,'data',data);

    gcbf=handles.figlab;
    delete(gcbf);
    
return;