function  varargout = corrector(varargin)
%% Psychological Test Toolbox: Scoring Utility v 1.00 %%%%%%%%%
%
% This program is the corrector of Psychological Test Toolbox, and it is
% designed to provide the factor scores based on additional participant's
% scores, using the original scores calculated previously with the main
% program.
%
% For detailed info about the program, please go to:
% http://psico.fcep.urv.cat/utilitats/PsychologicalTestToolbox
%
% Licensing:
%   This code is distributed under the GNU General Public License version
%   3.
%
% Authors:
%   David Navarro-Gonzalez
%   Andreu Vigil-Colet
%   Pere Joan Ferrando
%   Urbano Lorenzo-Seva
%
% Universitat Rovira i Virgili
% June, 2017
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin == 0  % LAUNCH GUI

% Data structure

% Path of raw data
data.path_X=[];

% Path of dispersion matrix provided by user
data.path_S=[];

% Path of file containing labels
data.path_labels=[];

% Path of file containing target matrix
data.path_target=[];

%Original number of participants (with and without missing data)
data.N_original=[];

%Number of participants (without missing data)
data.N=[];

% Number of variables
data.n=[];

% If there're some missing data (user defined)
data.missings_on=[];

% Missings value assigned
data.missings_value =[];

% Document name
data.name=[];

% Document path
data.path=[];

% If the user provides the matrix
data.matrix_user_on=[];

% Matrix with all the items
data.X=[];

% Correlation matrix, defined by the user
data.S=[];

% Variable labels
data.labels=[];

% Variable labels of the selected items
data.labelsa=[];

% If the labels are provided by the user
data.labels_user_on=0;

% Target rotation matrix
data.H=[];

% Matrix with the selected items
data.Xa=[];

% Matrix ready for the factorial analysis, only including the selected items
% and placing first the SD items
data.X_a=[];

% User defined matrix, only containing the selected items
data.Sa=[];

% Matrix ready for the factorial analysis, only including the selected items
% and placing first the SD items (user defined matrix)
data.S_a=[];

% Included items index
data.inclosos=[];

% Excluded items index
data.exclosos=[];

% Content items index
data.items_contingut=[];

% SD items index
data.items_sd=[];

% Missings position, composed by 0 (no missing value) and 1 (missing value)
data.missings_position=[];

% Vector with SD items number and content items [G(1) G(2)]
data.G=[];

% Type of matrix computed for the following analysis
data.Matrix=2; %Pearson by default

% If the user wants factorial socres
data.pfactorial=0;  %By default NO

% Rotation type for the factorial analysis
data.Rotation=2; % Oblique by default

% Set the letter for the menus
data.font = ChooseFont('Helvetica','Arial','MS Sans Serif');

% If the save output will be in latex mode
data.latex_on=0;    %per defecte, text pla

% If the save output will be in rtf style
data.rtf_on=0;     %per defecte, text pla

% If the save output will be in latex mode
data.latex2_on=0;    %per defecte, text pla

% If the save output will be in rtf style
data.rtf2_on=0;     %per defecte, text pla

% Polychoric matrix is calculated
data.Rp_all=[];

%If Acquiescence control function is enabled (NO by default)
data.checking_AQ=0;

%If Social Desirability control function is enabled (NO by default)
data.checking_DS=0;

% A marker for warning about losing data when loading a new analysis
data.Bandera=0; % NO Warning by default

%%%%%%%%% NEW VARIABLES %%%%%%%%%%%

%New data
data.X_new=[];

%New data ready to analyze
data.Xa_new=[];

%New number of participants
data.N_new=[];    

%New file name
data.name_new=[];

%New data path
data.path_new=[];

%If there're some missing data
data.missings_on_new=[];

% Missings value assigned
data.missings_value_new =[];

% If the save output will be in latex mode
data.latex_new_on=0;    %per defecte, text pla

% If the save output will be in rtf style
data.rtf_new_on=0;     %per defecte, text pla

% Code variable with the version of the program
data.version='4A1E26E9-F2CF-425B-A794-B1A00APTT106';

% Actual date
buff1=clock;
c=fix(buff1);
month={};
month{1}='January';month{2}='February';month{3}='March';month{4}='April';month{5}='May';month{6}='June';
month{7}='July';month{8}='August';month{9}='September';month{10}='October';month{11}='November';month{12}='December';
actual_month=month{c(2)};
buff=sprintf('%.0f-%s-%.0f, %.0f:%.0f',c(3),actual_month,c(1),c(4),c(5));
data.actual_date=buff;

%%%% Output structure %%%%
Printer.text=[];
Printer.latex=[];
Printer.rtf=[];

% Available at any time
setappdata(0,'data',data);
setappdata(0,'Printer',Printer);

finestra.N=760;
finestra.M=600;
pantalla=get(0,'ScreenSize');
finestra.coordenades=[(pantalla(3)/2)-(finestra.N/2)  (pantalla(4)/2)-(finestra.M/2) finestra.N finestra.M];

%Crear figura
handles.fig_scoring = figure('Units','Pixels',...
    'color' , [0.941 0.941 0.941],...
    'Position',finestra.coordenades);
tmp=get(0,'FactoryUIControlBackgroundColor');
set(handles.fig_scoring, 'MenuBar','none','Name','Psychological Test Toolbox: Scoring Utility','Toolbar','none','NumberTitle','off','resize','off');

%%%%%Crear MENUS
%Menu File
handles.MenuFile = uimenu('Label','File');
handles.MenuFile_Open = uimenu(handles.MenuFile,...
                                    'checked','off',...
                                    'Label','Import data parameters',...
                                    'Separator','on');
handles.MenuFile_ClearData = uimenu(handles.MenuFile,...
                                'checked','off',...
                                'Label','Clear data',...
                                'Separator','on');
handles.MenuFile_Quit = uimenu(handles.MenuFile,...
                                'checked','off',...
                                'Label','Quit',...
                                'Separator','on');
                            
%Menu Help
handles.MenuHelp = uimenu('Label','Help');
handles.MenuHelp_About = uimenu(handles.MenuHelp,...
                                    'checked','off',...
                                    'Label','About Psychological Test Toolbox: Scoring Utility');
handles.MenuHelp_Help = uimenu(handles.MenuHelp,...
                                    'checked','off',...
                                    'Label','Help');                             

%%Agrupacio de pestanyes
handles.hTabGroup = uitabgroup('parent',handles.fig_scoring);


%%TAB I PANEL DE LA PORTADA
handles.tab(1) = uitab(handles.hTabGroup,'title','Front Page','Units','pixels');
handles.panel_tab1=uipanel('parent',handles.tab(1),'Units','pixels','BackgroundColor', [1 .8 .6]);

%AXES PEL LOGO
logo.axes = axes('parent',handles.panel_tab1,...
   'Position',[0.2 0.15 0.6 0.6],...
   'XGrid','off',...
    'YGrid','off',...
    'Layer','top');
axis(logo.axes,'equal','off',[0 120 0 100 0 130]);

%DRAW LOGO
logo.fac = [1 2 3 4; ...
    2 6 7 3; ...
    4 3 7 8; ...
    1 5 8 4; ...
    1 2 6 5; ...
    5 6 7 8];
%(x,y,z,t);
%x,y,z defineixen posicio
% t defineix el tamany
logo.cube=zeros(8,3,21);
%grups de 7
%grup 1
logo.cube(:,:,1)=DefineCube(15,60,60,8);

logo.cube(:,:,2)=DefineCube(35,15,90,5);
logo.cube(:,:,3)=DefineCube(35,55,30,5);
logo.cube(:,:,4)=DefineCube(35,25,60,5);
logo.cube(:,:,5)=DefineCube(35,25,15,5);
logo.cube(:,:,6)=DefineCube(35,55,105,5);
logo.cube(:,:,7)=DefineCube(35,75,75,5);
logo.cube(:,:,8)=DefineCube(35,95,45,5);
%grup 2
logo.cube(:,:,9)=DefineCube(60,15,60,5);
logo.cube(:,:,10)=DefineCube(60,55,25,8);
logo.cube(:,:,11)=DefineCube(60,55,75,5);
logo.cube(:,:,12)=DefineCube(60,85,95,8);
logo.cube(:,:,13)=DefineCube(60,95,45,5);
%grup 3
logo.cube(:,:,14)=DefineCube(85,5,45,5);
logo.cube(:,:,15)=DefineCube(85,75,90,5);
logo.cube(:,:,16)=DefineCube(85,25,75,5);
logo.cube(:,:,17)=DefineCube(85,45,15,5);
logo.cube(:,:,18)=DefineCube(85,55,105,5);
logo.cube(:,:,19)=DefineCube(85,95,60,5);
logo.cube(:,:,20)=DefineCube(85,65,30,5);

logo.cube(:,:,21)=DefineCube(105,50,60,8);
logo.xv = 50;
logo.yv = 25;
logo.inc= -10;
patch('Faces',logo.fac,'Vertices',logo.cube(:,:,1),'FaceColor',[1 1 0]);  % patch function
material shiny;
% alpha('color');
alphamap('rampdown');
for i=2:8
    patch('Faces',logo.fac,'Vertices',logo.cube(:,:,i),'FaceColor',[.2 1 .2]);  % patch function
    material shiny;
%     alpha('color');
    alphamap('rampdown');
end;
for i=9:13
    patch('Faces',logo.fac,'Vertices',logo.cube(:,:,i),'FaceColor',[0 1 1]);  % patch function
    material shiny;
%     alpha('color');
    alphamap('rampdown');
end;
for i=14:20
    patch('Faces',logo.fac,'Vertices',logo.cube(:,:,i),'FaceColor',[.2 .2 1]);  % patch function
    material shiny;
%     alpha('color');
    alphamap('rampdown');
end;
patch('Faces',logo.fac,'Vertices',logo.cube(:,:,21),'FaceColor',[1 0 1]);  % patch function
material shiny;
alpha 0.5
alphamap('rampdown');
%random view
logo.x_initial=randi([31 46],1,1);
logo.y_initial=randi([6 21],1,1);
view(logo.x_initial,logo.y_initial);
logo.xv = logo.x_initial;
logo.yv = logo.y_initial;
logo.congratulations=0;
%view(51,26);
%SAVE LOGO
setappdata(0,'logo',logo);

handles.slider01=uicontrol(handles.panel_tab1,'Style','slider',...
    'Units','pixels',...
    'position',[240 80 280 20],...
    'min',0,...
    'max',66,...
    'value',0);

handles.slider02=uicontrol(handles.panel_tab1,'Style','slider',...
    'Units','pixels',...
    'position',[200 120 20 260],...
    'min',0,...
    'max',37,...
    'value',0);

%NOM DEL PROGRAMA
handles.text01=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 520 760 40],...
    'FontSize',22,...
    'fontname',char(data.font),...
    'ForegroundColor',[.8 .2 .2],...
    'HorizontalAlignment','center',...
    'FontWeight','bold',...
    'BackgroundColor', [1 .8 .6],...
    'String','Psychological Test Toolbox');

handles.text012=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 490 760 40],...
    'FontSize',18,...
    'fontname',char(data.font),...
    'ForegroundColor',[.8 .2 .2],...
    'HorizontalAlignment','center',...
    'FontWeight','bold',...
    'BackgroundColor', [1 .8 .6],...
    'String','Scoring Utility');

%AUTORS
handles.text021=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 450 760 50],...
    'FontSize',14,...
    'fontname',char(data.font),...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','center',...
    'BackgroundColor', [1 .8 .6],...
    'String','David Navarro-Gonzalez, Andreu Vigil-Colet,');

handles.text022=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 425 760 50],...
    'FontSize',14,...
    'fontname',char(data.font),...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','center',...
    'BackgroundColor', [1 .8 .6],...
    'String','Pere J. Ferrando, Urbano Lorenzo-Seva');

%Release
handles.text03=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 395 760 50],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','center',...
    'BackgroundColor', [1 .8 .6],...
    'String','Release Version 1.00');
%Any
handles.text04=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 400 760 20],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','center',...
    'BackgroundColor', [1 .8 .6],...
    'String','2017');
%urv
handles.text05=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 20 760 40],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','center',...
    'BackgroundColor', [1 .8 .6],...
    'String','Research Center for Behavior Assessment');
handles.text06=uicontrol(handles.panel_tab1,'Style','text',...
    'Units','pixels',...
    'position',[0 0 760 40],...
    'FontSize',12,...
    'fontname',char(data.font),...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','center',...
    'BackgroundColor', [1 .8 .6],...
    'String','Universitat Rovira i Virgili, Tarragona (Spain)');

% handles.slider01=uicontrol(handles.panel_tab1,'Style','slider',...
%     'Units','pixels',...
%     'position',[200 80 360 20],...
%     'min',0,...
%     'max',25,...
%     'value',0);

%%DATA PANEL
handles.tab(2) = uitab(handles.hTabGroup,'title','Data','Units','pixels');
handles.panel_tab2=uipanel('parent',handles.tab(2),'Units','pixels','BackgroundColor', [.941 .941 .941]);

%PANEL 1
handles.panel2_tab2=uipanel('parent',handles.panel_tab2,'Units','pixels',...
    'BackgroundColor', [.941 .941 .941],...
    'position',[10 480 735 80],...
    'FontSize',13,...
    'visible','on',...
    'fontname',char(data.font),...
    'Title','1st step: Import data parameters');

handles.axes1 = axes('parent',handles.panel2_tab2,...
    'units','pixels',...
   'Position',[5 12 30 30],...
   'XGrid','off',...
    'YGrid','off',...
    'Layer','top',...
    'visible','off');

%STRING DEL ANALYSIS
handles.analysis_string= uicontrol(handles.panel2_tab2,'Style','edit',...
    'Units','pixels',...
    'position',[45 15 500 25],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'max',0,...  
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'HorizontalAlignment','left',...
    'Enable','off',...
    'BackgroundColor', [1 1 1],...
    'String','');

%PUSH BUTTON import analysis
handles.import_analysis= uicontrol(handles.panel2_tab2,'Style','Pushbutton',...
    'Units','pixels',...
    'position',[565 10 120 40],...
    'Fontname',char(data.font),...
    'Fontsize',14,...
    'ForegroundColor',[.8 .2 .2],...
    'BackgroundColor',[.831 .816 .784],...
    'String','Browse',...
    'enable','on');


%PUSH BUTTON help
handles.help_button= uicontrol(handles.panel2_tab2,'Style','Pushbutton',...
    'Units','pixels',...
    'position',[692 12 32 32],...
    'Fontname',char(data.font),...
    'Fontsize',14,...
    'ForegroundColor',[.8 .2 .2],...
    'BackgroundColor',[.831 .816 .784],...
    'String','',...
    'enable','on');

img=imread('question30w2.png','png');
img=double(img)/255;
index1=img(:,:,1)==1;
index2=img(:,:,2)==1;
index3=img(:,:,3)==1;

indexWhite = index1+index2+index3==3;
for idx = 1 : 3
   rgb = img(:,:,idx);     % extract part of the image
   rgb(indexWhite) = NaN;  % set the white portion of the image to NaN
   img(:,:,idx) = rgb;     % substitute the update values
end
set(handles.help_button, 'CData', img)     % Update the CData variable


%PANEL 2
handles.panel3_tab2=uipanel('parent',handles.panel_tab2,'Units','pixels',...
    'BackgroundColor', [.941 .941 .941],...
    'position',[10 350 735 120],...
    'FontSize',13,...
    'visible','off',...
    'fontname',char(data.font),...
    'Title','2nd step: Add participant''s scores');

%RADIOBUTTON OF IMPORT NEW DATA FILE
handles.Import_new_data_file = uicontrol(handles.panel3_tab2,...
    'style','radiobutton',...
    'string','Import new data file',...
    'fontname',char(data.font),...
    'FontSize',13,...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','left',...
    'value',1,...
    'BackgroundColor', [.941 .941 .941],...
    'position',[15 60 300 20]);

%STRING DE NEW DATA
handles.new_data_string= uicontrol(handles.panel3_tab2,'Style','edit',...
    'Units','pixels',...
    'position',[220 60 350 25],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'max',0,...  
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'HorizontalAlignment','left',...
    'Enable','off',...
    'BackgroundColor', [1 1 1],...
    'String','');

%PUSH BUTTON DEL READ NEW DATA
handles.import_new_data= uicontrol(handles.panel3_tab2,'Style','Pushbutton',...
    'Units','pixels',...
    'position',[605 55 120 40],...
    'Fontname',char(data.font),...
    'Fontsize',14,...
    'ForegroundColor',[.8 .2 .2],...
    'BackgroundColor',[.831 .816 .784],...
    'String','Browse',...
    'enable','off');

%RADIOBUTTON OF PROVIDE NEW DATA MANUALLY
handles.Provide_new_data_manually = uicontrol(handles.panel3_tab2,...
    'style','radiobutton',...
    'string','Provide new data manually',...
    'fontname',char(data.font),...
    'FontSize',13,...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','left',...
    'value',0,...
    'BackgroundColor', [.941 .941 .941],...
    'position',[15 15 300 25]);

% PARTICIPANTS SELECTED LABEL
handles.text_participants_labels= uicontrol(handles.panel3_tab2,'Style','text',...
    'Units','pixels',...
    'position',[350 15 260 20],...
    'FontSize',14,...
    'fontname',char(data.font),...
    'ForegroundColor',[.8 .2 .2],...
    'HorizontalAlignment','left',...
    'FontWeight','bold',...
    'BackgroundColor', [.941 .941 .941],...
    'String','New participant''s scores added',...
    'visible','off');

% LIST OF PARTICIPANT'S SCORES
handles.Participants_number= uicontrol(handles.panel3_tab2,'Style','edit',...
    'Units','pixels',...
    'position',[630 10 60 25],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'TooltipString','Number of new cases added in the tab "Provide data manually"',...
    'max',0,...  
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'Enable','off',...
    'HorizontalAlignment','right',...
    'BackgroundColor', [.941 .941 .941],...
    'String','',...
    'visible','off');

%ETIQUETA DEL QUADRE DE OUTPUT DELS DESCRIPTIUS
handles.text13= uicontrol(handles.panel_tab2,'Style','text',...
    'Units','pixels',...
    'position',[10 305 400 20],...
    'fontname',char(data.font),...
    'FontSize',13,...
    'FontWeight','bold',...
    'ForegroundColor',[.2 .2 .2],...
    'HorizontalAlignment','left',...
    'BackgroundColor', [.941 .941 .941],...
    'String','Descriptive Statistics: Output',...
    'visible','off');

%PUSH BUTTON OPTIONAL FACTOR STRINGS
handles.factor_labels= uicontrol(handles.panel_tab2,'Style','Pushbutton',...
    'Units','pixels',...
    'position',[10 305 280 30],...
    'Fontname',char(data.font),...
    'Fontsize',14,...
    'ForegroundColor',[.8 .2 .2],...
    'BackgroundColor',[.831 .816 .784],...
    'String','Set factor labels (optional)',...
    'visible','off',...
    'enable','on');

handles.ModelOutputDecrementa= uicontrol(handles.panel_tab2,'string','-',...
    'Style','pushbutton',...
    'Units','pixels',...
    'position',[675 305 30 30],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'Enable','off',...
    'TooltipString','Zoom out',...
    'BackgroundColor', [.831 .816 .784],...
    'ForegroundColor',[.8 .2 .2],...  
    'HorizontalAlignment','center',...
    'FontWeight','normal',...
    'visible','off');

handles.ModelOutputIncrementa= uicontrol(handles.panel_tab2,'string','+',...
    'Style','pushbutton',...
    'Units','pixels',...
    'position',[714 305 30 30],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'Enable','off',...
    'TooltipString','Zoom out',...
    'BackgroundColor', [.831 .816 .784],...
    'ForegroundColor',[.8 .2 .2],...  
    'HorizontalAlignment','center',...
    'FontWeight','normal',...
    'visible','off');

tmp={};
global outputletter;
outputletter = 12;
handles.ModelOutput= uicontrol(handles.panel_tab2,'Style','listbox',...
    'Units','pixels',...
    'position',[10 60 735 240],...
    'FontSize',outputletter,...
    'fontname','Monospaced',...
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'visible','on',...
    'HorizontalAlignment','left',...
    'min',0,'max',0,...
    'FontWeight','normal',...
    'String',tmp);

handles.ModelOutput_latex= uicontrol(handles.panel_tab2,'Style','listbox',...
    'Units','pixels',...
    'position',[10 60 735 240],...
    'FontSize',outputletter,...
    'fontname','Monospaced',...
    'Visible','off',...
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'HorizontalAlignment','left',...
    'min',0,'max',0,...
    'FontWeight','normal',...
    'String',tmp);

handles.ModelOutput_rtf= uicontrol(handles.panel_tab2,'Style','listbox',...
    'Units','pixels',...
    'position',[10 60 735 240],...
    'FontSize',outputletter,...
    'fontname','Monospaced',...
    'Visible','off',...
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'HorizontalAlignment','left',...
    'min',0,'max',0,...
    'FontWeight','normal',...
    'String',tmp);

%Radio button save as text
handles.save_text= uicontrol(handles.panel_tab2,'Style','radiobutton',...
    'Units','pixels',...
    'position',[15 35 120 20],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'Value',1,...
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'Enable','off',...
    'HorizontalAlignment','right',...
    'BackgroundColor', [.941 .941 .941],...
    'String','Text',...
    'visible','off');

%Radio button save as rtf
handles.save_rtf= uicontrol(handles.panel_tab2,'Style','radiobutton',...
    'Units','pixels',...
    'position',[90 35 120 20],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'Value',0,...
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'Enable','off',...
    'HorizontalAlignment','right',...
    'BackgroundColor', [.941 .941 .941],...
    'String','RTF',...
    'visible','off');

%Radio button save as latex
handles.save_latex= uicontrol(handles.panel_tab2,'Style','radiobutton',...
    'Units','pixels',...
    'position',[150 35 120 20],...
    'FontSize',13,...
    'fontname',char(data.font),...
    'Value',0,...
    'BackgroundColor',[1 1 1],...
    'ForegroundColor',[0 0 0],...  
    'Enable','off',...
    'HorizontalAlignment','right',...
    'BackgroundColor', [.941 .941 .941],...
    'String','Latex',...
    'visible','off');

%BOTON SALVAR L'OUTPUT A UN FITXER TEXT
handles.ButtonSalvarOutput = uicontrol(handles.panel_tab2,'String','Save Output',...
    'Style','pushbutton',...
    'FontSize',15,...
    'FontWeight','bold',...
    'fontname',char(data.font),...   
    'position',[15 10 200 40],...
    'enable','off',...
    'TooltipString','To save the output of the fitted model as a text file',...
    'BackgroundColor', [.831 .816 .784],...
    'ForegroundColor',[.8 .2 .2]);

%BOTON LAUNCH L'OUTPUT A UN FITXER TEXT
handles.ButtonLaunchOutput = uicontrol(handles.panel_tab2,'String',' Visualize Output ',...
    'Style','pushbutton',...
    'FontSize',15,...
    'FontWeight','bold',...
    'fontname',char(data.font),...   
    'position',[240 10 240 40],...
    'enable','off',...
    'TooltipString','To launch the output of the fitted model in a new window',...
    'BackgroundColor', [.831 .816 .784],...
    'ForegroundColor',[.8 .2 .2]);

%PUSH BUTTON DEL COMPUTE
handles.compute= uicontrol(handles.panel_tab2,'Style','Pushbutton',...
    'Units','pixels',...
    'position',[505 10 240 40],...
    'FontSize',15,...
    'FontWeight','bold',...
    'fontname',char(data.font),... 
    'ForegroundColor',[.8 .2 .2],...
    'BackgroundColor',[.831 .816 .784],...
    'String','Compute',...
    'enable','off');

%%VIEW DATA PANEL
handles.tab(3) = uitab(handles.hTabGroup,'title','Provide data manually','Units','pixels');
handles.panel_tab3=uipanel('parent',handles.tab(3),'Units','pixels','BackgroundColor', [.941 .941 .941],...
    'visible','on');
handles.data_table = uitable(handles.panel_tab3,'units','normalized','Position', [.025 .10 .95 .82],'visible','off');
set(handles.data_table,'ColumnWidth',{50},...
    'ColumnEditable',true);
%     'CellEditCallback',@converttonum);

%PUSH BUTTON DEL Provide
handles.provide= uicontrol(handles.panel_tab3,'Style','Pushbutton',...
    'Units','pixels',...
    'position',[505 10 240 40],...
    'FontSize',15,...
    'FontWeight','bold',...
    'fontname',char(data.font),... 
    'ForegroundColor',[.8 .2 .2],...
    'BackgroundColor',[.831 .816 .784],...
    'String','Provide data',...
    'visible','off');

%%%% CALLBACK SECTION %%%%

%MENU


set(handles.MenuFile_Open,...
    'Callback',{@Import_Callback, handles});
set(handles.MenuFile_ClearData,...
    'Callback',{@ClearData_Callback, handles});
set(handles.MenuFile_Quit,...
    'Callback',{@QuitCallback, handles});

set(handles.MenuHelp_About,...
    'Callback',{@About_Callback, handles});
set(handles.MenuHelp_Help,...
    'Callback',{@HelpCallback, handles});

%%%% front page %%%%
set(handles.slider01,...
    'Callback',{@Slider_Callback, handles});
set(handles.slider02,...
    'Callback',{@Slider_Callback2, handles});



handles.context_menu=uicontextmenu;
set(handles.text01,'UIContextMenu',handles.context_menu);

% handles.item1=uimenu(handles.context_menu,'Label','Eastern Egg');

%easter egg
% set(handles.item1,...
%     'Callback',{@easter_egg, handles});
%music
% set(handles.music,...
%     'Callback',{@music, handles});

%%%% TAB 1 %%%%

% IMPORT PREVIOUS ANALYSIS
set(handles.import_analysis,...
    'Callback',{@Import_Callback, handles});

% IMPORT NEW DATA
set(handles.import_new_data,...
    'Callback',{@Import_new_data_Callback, handles});

% HELP PUSH BUTTON
set(handles.help_button,...
    'Callback',{@Help_button_Callback, handles});

%IMPORT DATA FROM FILE
set(handles.Import_new_data_file,...
    'Callback',{@Type_new_data, handles,1});

%PROVIDE DATA MANUALLY
set(handles.Provide_new_data_manually,...
    'Callback',{@Type_new_data, handles,2});

%Provide factor labels
set(handles.factor_labels,...
    'Callback',{@Provide_Labels, handles});

%COMPUTE
set(handles.compute,...
    'Callback',{@Compute_Callback, handles});

%ZOOM out
set(handles.ModelOutputDecrementa,...
    'Callback',{@ModelOutputDecrementa_Callback, handles, 1});
%ZOOM in
set(handles.ModelOutputIncrementa,...
    'Callback',{@ModelOutputDecrementa_Callback, handles, 2});

%save in text
set(handles.save_text,...
    'Callback',{@Savetype_Callback, handles,1});
%save in rtf
set(handles.save_rtf,...
    'Callback',{@Savetype_Callback, handles,2});
%save in latex
set(handles.save_latex,...
    'Callback',{@Savetype_Callback, handles,3});
%salvar output 1
set(handles.ButtonSalvarOutput,...
    'Callback',{@ButtonSalvarOutput_Callback,handles});
%llença l'output en una nova finestra 1
set(handles.ButtonLaunchOutput,...
    'Callback',{@ButtonLaunchOutput_Callback, handles});

%%%% TAB 2 %%%%
set(handles.provide,...
    'Callback',{@Provide_Callback, handles});

handles.add_rows=uicontextmenu;
set(handles.data_table,'UIContextMenu',handles.add_rows);

handles.add_rows1=uimenu(handles.add_rows,'Label','Add more rows');

set(handles.add_rows1,...
    'Callback',{@Add_rows_Callback, handles});

if nargout > 0
     varargout{1} = handles.fig_scoring;
end


elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

    try
        if (nargout)
            [varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
        else
            feval(varargin{:}); % FEVAL switchyard
        end
    catch
        disp(lasterr);
    end

end

function Slider_Callback(hObject, eventdata,handles)

    pos=get(handles.slider01,'value');
    logo=getappdata(0,'logo');
    pos2=logo.x_initial-pos;    
    logo.xv = pos2;
%     logo.yv = pos2;
    setappdata(0,'logo',logo);
    
    axes(logo.axes);
    if logo.xv<=1 && logo.xv>=-2 && logo.yv<=1 && logo.yv>=-1
        view(0,0);
        if logo.congratulations==0
            %msgbox('Congratulations! You have successfully aligned the factors.');
            msgbox('Congratulations! You have fit the model');
            
            color_selected=[.6 .7 .9];
            
            set(handles.panel_tab1,'backgroundcolor',color_selected);
            set(handles.text01,'backgroundcolor',color_selected);
            set(handles.text012,'backgroundcolor',color_selected);
            set(handles.text021,'backgroundcolor',color_selected);
            set(handles.text022,'backgroundcolor',color_selected);
            set(handles.text03,'backgroundcolor',color_selected);
            set(handles.text04,'backgroundcolor',color_selected);
            set(handles.text05,'backgroundcolor',color_selected);
            set(handles.text06,'backgroundcolor',color_selected);
            
            logo.congratulations=1;
            setappdata(0,'logo',logo);
        end;
        
    else
        view(logo.xv,logo.yv);
    end;

return;

function Slider_Callback2(hObject, eventdata,handles)

    pos=get(handles.slider02,'value');
    logo=getappdata(0,'logo');
    pos2=logo.y_initial-pos;    
%     logo.xv = pos2*2;
    logo.yv = pos2;
    setappdata(0,'logo',logo);
    
    axes(logo.axes);
    if logo.xv<=1 && logo.xv>=-2 && logo.yv<=1 && logo.yv>=-1
        view(0,0);
        if logo.congratulations==0
            %msgbox('Congratulations! You have successfully aligned the factors.');
            msgbox('Congratulations! You have fit the model');
            color_selected=[.6 .7 .9];
            
            set(handles.panel_tab1,'backgroundcolor',color_selected);
            set(handles.text01,'backgroundcolor',color_selected);
            set(handles.text012,'backgroundcolor',color_selected);
            set(handles.text021,'backgroundcolor',color_selected);
            set(handles.text022,'backgroundcolor',color_selected);
            set(handles.text03,'backgroundcolor',color_selected);
            set(handles.text04,'backgroundcolor',color_selected);
            set(handles.text05,'backgroundcolor',color_selected);
            set(handles.text06,'backgroundcolor',color_selected);
            
            logo.congratulations=1;
            setappdata(0,'logo',logo);
        end;
    else
        view(logo.xv,logo.yv);
    end;
    
return;


% function Slider_Callback(hObject, eventdata,handles)
% 
%     pos=get(handles.slider01,'value');
%     pos2=25-pos;
%     logo=getappdata(0,'logo');
%     logo.xv = pos2*2;
%     logo.yv = pos2;
%     setappdata(0,'logo',logo);
%     axes(logo.axes);
%     view(logo.xv,logo.yv);
% 
% return;

function ClearData_Callback(hObject, eventdata, handles)
% hObject    handle to ClearData (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

data=getappdata(0,'data');

if isempty(data.X) && isempty(data.S)
        errordlg('There are no data avaible','Psychological Test Toolbox: Error');
        return;
else
    ButtonName=questdlg('Do you want to clear the data in memory','Psychological Test Toolbox','Yes','No','No'); 
    switch ButtonName
    case 'No'
	    % take no action
    case 'Yes'
        evalin('base','clear');
        evalin('base','clc');
        tmp1={};
        
        set(handles.analysis_string,'string','');
        set(handles.panel3_tab2,'visible','off');
        
        Type_new_data(gcf, eventdata, handles , 1);
        
        set(handles.factor_labels,'visible','off');
        set(handles.ModelOutputDecrementa,'visible','off','enable','off');
        set(handles.ModelOutputIncrementa,'visible','off','enable','off');
        set(handles.ModelOutput,'string',tmp1);
        set(handles.ModelOutput_latex,'string',tmp1);
        set(handles.ModelOutput_rtf,'string',tmp1);
        set(handles.ButtonSalvarOutput,'enable','off');
        set(handles.ButtonLaunchOutput,'enable','off');
        set(handles.compute,'enable','off');
        set(handles.data_table,'data',tmp1,'visible','off');
        set(handles.provide,'visible','off');
        
        cla(handles.axes1);
        
        %LOAD DATA
        data=getappdata(0,'data');
        data.N=[];
        data.N_sensemiss=[];
        data.N_original=[];
        data.missings_value=[];
        data.missings_position=[];
        data.n=[];
        data.name=[];
        data.path=[];
        data.missings_on=0;
        data.matrix_user_on=[];
        data.X=[];
        data.Xa=[];
        data.X_a=[];
        data.X_sensemiss=[];
        data.X_sensemissa=[];
        data.Xm=[];
        data.S=[];
        data.Sa=[];
        data.S_a=[];
        data.labels=[];
        data.labelsa=[];
        data.labels_user_on=[];
        data.H=[];
        data.inclosos=[];
        data.exclosos=[];
        data.Matrix=2;
        data.Rotation=2;
        data.items_contingut=[];
        data.exclosos=[];
        data.items_sd=[];
        data.G=[];
        data.A=[];
        data.A1=[];
        data.Re_cont=[];
        data.Re_final=[];
        data.latex_on=0;
        data.rtf_on=0;
        data.latex2_on=0;
        data.rtf2_on=0;
        data.itemsa=[];
        data.ib=[];
        data.iba=[];
        data.iub=[];
        data.iuba=[];
        data.Hc=[];
        data.R=[];
        data.SS=[];
        data.Rp=[];
        data.thresholds=[];
        data.time_poly=[];
        data.labels_contingut=[];
        data.full_analysis=0;
        data.PHI=[];
        data.PHIt=[];
        data.PHIi=[];
        data.PHIr=[];
        data.P=[];
        data.Pc=[];
        data.IRT_A=[];
        data.IRT_D=[];
        data.IRT_MDISC=[];
        data.IRT_B=[];
        data.IRT_A1=[];
        data.Ygrad=[];
        data.th=[];
        data.Lc=[];
        data.Lz=[];
        data.th_li=[];
        data.th_ls=[];
        data.se=[];
        data.reli=[];
        data.th=[];
        data.th_all=[];
        data.Xpredicted=[];
        data.WLSRegression=[];
        data.corr_error=0;
        data.items_corr_error=[];
        data.descriptives_done=0;
        data.forced_descriptives=0;
        data.Rotation=2;
        
        %New data
        data.X_new=[];
        data.Xa_new=[];
        data.N_new=[];    
        data.name_new=[];
        data.path_new=[];
        data.missings_on_new=[];
        data.missings_value_new =[];
        data.latex_new_on=0;
        data.rtf_new_on=0;
        
        setappdata(0,'data',data);
        
        set(gcbf,'Pointer','arrow')
        
        evalin('base','clc');
        drawnow;
        
        set(handles.hTabGroup,'Selectedtab',handles.tab(2))
    end;   
end;
return

function Forced_ClearData_Callback(hObject, eventdata, handles)
% hObject    handle to ClearData (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

    data=getappdata(0,'data');

    evalin('base','clear');
    evalin('base','clc');
    tmp1={};

    set(handles.analysis_string,'string','');
    set(handles.panel3_tab2,'visible','off');

    Type_new_data(gcf, eventdata, handles , 1);

    set(handles.factor_labels,'visible','off');
    set(handles.ModelOutputDecrementa,'visible','off','enable','off');
    set(handles.ModelOutputIncrementa,'visible','off','enable','off');
    set(handles.ModelOutput,'string',tmp1);
    set(handles.ModelOutput_latex,'string',tmp1);
    set(handles.ModelOutput_rtf,'string',tmp1);
    set(handles.ButtonSalvarOutput,'enable','off');
    set(handles.ButtonLaunchOutput,'enable','off');
    set(handles.compute,'enable','off');
    set(handles.data_table,'data',tmp1,'visible','off');
    set(handles.provide,'visible','off');

    cla(handles.axes1);
    
    data.N=[];
    data.N_sensemiss=[];
    data.N_original=[];
    data.missings_value=[];
    data.missings_position=[];
    data.n=[];
    data.name=[];
    data.path=[];
    data.missings_on=0;
    data.matrix_user_on=[];
    data.X=[];
    data.Xa=[];
    data.X_a=[];
    data.X_sensemiss=[];
    data.X_sensemissa=[];
    data.Xm=[];
    data.S=[];
    data.Sa=[];
    data.S_a=[];
    data.labels=[];
    data.labelsa=[];
    data.labels_user_on=[];
    data.H=[];
    data.inclosos=[];
    data.exclosos=[];
    data.Matrix=2;
    data.Rotation=2;
    data.items_contingut=[];
    data.exclosos=[];
    data.items_sd=[];
    data.G=[];
    data.A=[];
    data.A1=[];
    data.Re_cont=[];
    data.Re_final=[];
    data.latex_on=0;
    data.rtf_on=0;
    data.latex2_on=0;
    data.rtf2_on=0;
    data.itemsa=[];
    data.ib=[];
    data.iba=[];
    data.iub=[];
    data.iuba=[];
    data.Hc=[];
    data.R=[];
    data.SS=[];
    data.Rp=[];
    data.thresholds=[];
    data.time_poly=[];
    data.labels_contingut=[];
    data.full_analysis=0;
    data.PHI=[];
    data.PHIt=[];
    data.PHIi=[];
    data.PHIr=[];
    data.P=[];
    data.Pc=[];
    data.IRT_A=[];
    data.IRT_D=[];
    data.IRT_MDISC=[];
    data.IRT_B=[];
    data.IRT_A1=[];
    data.Ygrad=[];
    data.th=[];
    data.Lc=[];
    data.Lz=[];
    data.th_li=[];
    data.th_ls=[];
    data.se=[];
    data.reli=[];
    data.th=[];
    data.th_all=[];
    data.Xpredicted=[];
    data.WLSRegression=[];
    data.corr_error=0;
    data.items_corr_error=[];
    data.descriptives_done=0;
    data.forced_descriptives=0;
    data.Rotation=2;

    %New data
    data.X_new=[];
    data.Xa_new=[];
    data.N_new=[];    
    data.name_new=[];
    data.path_new=[];
    data.missings_on_new=[];
    data.missings_value_new =[];
    data.latex_new_on=0;
    data.rtf_new_on=0;

    setappdata(0,'data',data);

    set(gcbf,'Pointer','arrow')

    evalin('base','clc');
    drawnow;

    set(handles.hTabGroup,'Selectedtab',handles.tab(2))
    
return


function About_Callback (hObject,eventdata,handles,gcf)

text{1}='Psychological Test Toolbox: Scoring Utility';
text{2}='                      (version 1.00)';
text{3}=' ';
text{4}='David Navarro-Gonzalez, Andreu Vigil-Colet, ';
text{5}='Pere J. Ferrando & Urbano Lorenzo-Seva' ;
text{6}=' ';
text{7}='(Rovira i Virgili University, Tarragona, Spain) ';
text{8}='                              2017                 ';

msgbox(text,'About Psychological Test Toolbox: Scoring Utility');

return;

function HelpCallback (hObject,eventdata,handles,gcf)

web('http://psico.fcep.urv.cat/utilitats/PsychologicalTestToolbox/index.html','-browser');

return;

function QuitCallback (hObject,eventdata,handles,gcf)

ButtonName=questdlg('Do you want to quit the application','Psychological Test Toolbox: Scoring Utility','Yes','No','No'); 
    switch ButtonName
    case {'No','Cancel'}
	    % take no action
    case 'Yes'
        delete(gcbf);
    end 

return;

function Help_button_Callback (hObject,eventdata,handles,gcf)

text{1}='The first step is importing the analysis file, which';
text{2}='has to been generated using Psychological Test';
text{3}='Toolbox v 1.04 or later.';
text{4}=' ';
text{5}='The way the analyisis file is obtained is the following:';
text{6}='Once the analysis using the original program was';
text{7}='finished, select the option ''Save analysis'' from the' ;
text{8}='File Menu, and the resulting file (.mat extension) is the';
text{9}='required one on the Scoring Utility.';

helpdlg(text,'Psychological Test Toolbox: Scoring Utility');
return;

function Type_new_data(gcf, eventdata, handles , radio_value)

    %LOAD DATA
    data=getappdata(0,'data');
    import1=get(handles.Import_new_data_file,'value');
    import2=get(handles.Provide_new_data_manually,'value');

    switch radio_value       
        case 1
            if import1==1 && import2==1
                data.N_new=[];
                set(handles.compute,'enable','off');
                set(handles.Participants_number,'string','');                
            end;
            set(handles.Import_new_data_file,'value',1);
            set(handles.Provide_new_data_manually,'value',0);
            set(handles.new_data_string,'visible','on');
            set(handles.import_new_data,'visible','on');
            set(handles.text_participants_labels,'visible','off');
            set(handles.Participants_number,'visible','off');
            data.N_new=[];
%             set(handles.compute,'enable','off');
            
        case 2
            if import1==1
                data.N_new=[];
                set(handles.compute,'enable','off');
                set(handles.Participants_number,'string','');
                set(handles.new_data_string,'string','');
            end;
            set(handles.Import_new_data_file,'value',0);
            set(handles.Provide_new_data_manually,'value',1);
            set(handles.new_data_string,'visible','off');
            set(handles.import_new_data,'visible','off');
            set(handles.text_participants_labels,'visible','on');
            set(handles.Participants_number,'visible','on');
%             set(handles.analysis_string,'string','');
            %change current tab
            handles.hTabGroup.SelectedTab = handles.tab(3);

    end;

    %SAVE DATA 
    setappdata(0,'data',data);

return;

function ModelOutputDecrementa_Callback(hObject, eventdata, handles, accion)
global outputletter;

switch accion
    case 1
      if outputletter > 7 
         outputletter = outputletter - 1;
         set(handles.ModelOutput,'FontSize',outputletter);
      end;
    case 2
      if outputletter < 20
         outputletter = outputletter + 1;
         set(handles.ModelOutput,'FontSize',outputletter);
      end;
end;
return;

function ModelOutputDecrementa_Callback_File(hObject, eventdata, new_handle, accion)

tamany=get(new_handle,'FontSize');

switch accion
    case 1
      if tamany > 7
         tamany = tamany - 1;
         set(new_handle,'FontSize',tamany);
      end;
    case 2
      if tamany < 20
         tamany = tamany + 1;
         set(new_handle,'FontSize',tamany);
      end;
end;
return;

function Savetype_Callback(gcf, eventdata, handles, datatype_value)

    data=getappdata(0,'data');

    switch datatype_value
        case 1
            set(handles.save_text,'value',1);
            set(handles.save_rtf,'value',0);
            set(handles.save_latex,'value',0);
            data.latex_new_on=0;
            data.rtf_new_on=0;
        case 2
            set(handles.save_text,'value',0);
            set(handles.save_rtf,'value',1);
            set(handles.save_latex,'value',0);
            data.latex_new_on=0;
            data.rtf_new_on=1;
        case 3
            set(handles.save_text,'value',0);
            set(handles.save_rtf,'value',0);
            set(handles.save_latex,'value',1);
            data.latex_new_on=1;
            data.rtf_new_on=0;
    end;
    
    setappdata(0,'data',data);
return;

function ButtonSalvarOutput_Callback(hObject, eventdata, handles)
    
    data=getappdata(0,'data');
    comaposition=findstr(data.actual_date,',');

%     if data.latex_new_on==0 && data.rtf_new_on==0;
        buff= sprintf('output_%s.txt',data.actual_date(1:comaposition-1));
        [FILENAME, PATHNAME] = uiputfile({'.txt','Text files'}, 'Psychological Test Toolbox: Save output as a text file',buff);

        if FILENAME == 0
            return;
        end;

        try 
            FileDiary=[PATHNAME FILENAME];
            f=exist(FileDiary,'file');
            if f == 2
               eval(['delete ' FileDiary]);
            end;
            
            buff = get(handles.ModelOutput,'string');
            c=cellstr(buff);
            fileID = fopen(FileDiary,'w');
            fprintf(fileID,'%s\r\n',c{:});

            msgbox('File save complete','Psychological Test Toolbox');
            fclose(fileID);
        catch 
            msgbox(lasterr,'error');
        end;
        
return;


function ButtonLaunchOutput_Callback(hObject,eventdata,handles)

    h=handles.ModelOutput;

    finestra.N=760;
    finestra.M=600;
    pantalla=get(0,'ScreenSize');
    
    fig2=figure('units','pixels',...
        'position',[(pantalla(3)/2)-(finestra.N/2)-50  (pantalla(4)/2)-(finestra.M/2)-50 (finestra.N) (finestra.M)],...
        'MenuBar','none',...
        'Toolbar','none');
    
    
    handles.MenuFile2 = uimenu('Label','File');
    handles.MenuFile_Save_text = uimenu(handles.MenuFile2,...
                                        'Label','Save as text',...
                                        'checked','off',...
                                        'Callback',{@File_save_text, handles});
    handles.MenuFile_Save_rtf = uimenu(handles.MenuFile2,...
                                        'Label','Save as RTF',...
                                        'checked','off',...
                                        'Callback',{@File_save_rtf, handles});
    handles.MenuFile_Save_latex = uimenu(handles.MenuFile2,...
                                        'Label','Save as latex',...
                                        'checked','off',...
                                        'Callback',{@File_save_latex, handles}); 
%     handles.MenuFile_Save_scores = uimenu(handles.MenuFile2,...
%                                     'Label','Save scores',...
%                                     'Separator','on',...
%                                     'Callback',{@ButtonSalvarpfactors_Callback, handles});
    new_handle= copyobj(h,fig2);

    set(new_handle,'units','normalized',...
        'position',[.025 .025 .95 .95]);   
    
    t=uitoolbar;    
    pr=uipushtool(t,'TooltipString','Print the output',...
                'ClickedCallback',{@print_output, new_handle});
    icon=imread('printer.png');
    pr.CData=icon;
    
    decrement=uipushtool(t,'TooltipString','Zoom out',...
                'ClickedCallback',{@ModelOutputDecrementa_Callback_File, new_handle, 1});
    icon=imread('minus.png');
    decrement.CData=icon;
    
    increment=uipushtool(t,'TooltipString','Zoom in',...
                'ClickedCallback',{@ModelOutputDecrementa_Callback_File, new_handle, 2});
    icon=imread('plus.png');
    increment.CData=icon;

    set(fig2,'Name','Psychological Test Toolbox: Scoring Utility','NumberTitle','off');

return

function Add_rows_Callback (hObject,eventdata,handles)
    
    actual_cells=get(handles.data_table,'Data');

    [f1,f2]=size(actual_cells);
    buff_cell=cell(10,f2);
    buff_cell=[actual_cells;buff_cell];
    buff_numeric={};
    for i=1:f2
        buff_numeric=[buff_numeric 'numeric'];
    end;
        
    set(handles.data_table,'visible','on','Data',buff_cell);
    set(handles.data_table,'ColumnFormat',buff_numeric);
    set(handles.provide,'visible','on');
    
    setappdata(0,'data',data);

return

function Import_Callback (hObject,eventdata,handles)

    [filename1, pathname1] = uigetfile({'*.mat','Psychological Test Toolbox analysis (.mat)'},'Psychological Test Toolbox: Scoring Utility');
    
    if isequal(filename1,0)||isequal(pathname1,0)
        return;
    else
        
    load([pathname1 filename1]);
    
    %Check if data matrix is imported
    if exist('data','var')==1
        % No action
    else
        dlg{1}='No data structure found on the .mat file ';
        dlg{2}='please make sure that the file is succesful generated with Psychological Test Toolbox v1.04 or later.';
        errordlg(dlg,'Psychological Test Toolbox: Scoring Utility');
        
        Forced_ClearData_Callback(hObject, eventdata, handles);

        [im,map,alpha_channel]=imread('rojo_t.png','png');

        f=imshow(im,'parent',handles.axes1);
        set(f,'AlphaData',alpha_channel);
        set(handles.import_new_data,'enable','off');
        
        return;
    end;
    %Check if the .mat file is generated by Psychological Test Toolbox
    if isfield(data,'version')==0
        dlg{1}='The file imported was not generated by Psychological Test Toolbox v1.04 or later. ';
        dlg{2}='Please, download last version of the program from: ';
        dlg{3}='http://psico.fcep.urv.cat/utilitats/PsychologicalTestToolbox/download.html';
        
        errordlg(dlg,'Psychological Test Toolbox: Scoring Utility');
        
        Forced_ClearData_Callback(hObject, eventdata, handles);
        
        [im,map,alpha_channel]=imread('rojo_t.png','png');

        f=imshow(im,'parent',handles.axes1);
        set(f,'AlphaData',alpha_channel);
        set(handles.import_new_data,'enable','off');
        return;
    end;
    
    clear config Printer fn pn filterindex
    
    code=data.version;
    
    [f1,f2]=size(code);
    
    code_program=code(1:f2-3);
    code_version=code(f2-2:f2);
    
    verif=strcmp('4A1E26E9-F2CF-425B-A794-B1A00APTT',code_program);
    if verif==0
        dlg{1}='The file imported was not generated by Psychological Test Toolbox v1.04 or later. ';
        dlg{2}='Please, download last version of the program from: ';
        dlg{3}='http://psico.fcep.urv.cat/utilitats/PsychologicalTestToolbox/download.html';
        
        errordlg(dlg,'Psychological Test Toolbox: Scoring Utility');
        
        Forced_ClearData_Callback(hObject, eventdata, handles);
        
        [im,map,alpha_channel]=imread('rojo_t.png','png');

        f=imshow(im,'parent',handles.axes1);
        set(f,'AlphaData',alpha_channel);
        set(handles.import_new_data,'enable','off');
        return;
    end;
        
    
%         a=uiimport([pathname1 filename1]);
%         if isempty(a)
%             return;
%         end;
        
    set(handles.analysis_string,'string',[pathname1 filename1]);
        
%         if isfield(a,'data')==1
%             data=a.data;
%         else
%             errordlg('No data structure found on the .mat file, please do not uncheck any structure when importing','Psychological Test Toolbox: Scoring Utility');
% 
%             [im,map,alpha_channel]=imread('rojo_t.png','png');
% 
%             f=imshow(im,'parent',handles.axes1);
%             set(f,'AlphaData',alpha_channel);
%             set(handles.import_new_data,'enable','off');
%             return;
%         end;
%         
        
        
        % Check if the data is raw data, not dispersion matrix
        if data.matrix_user_on==1
            dlg1='The provided data is not sutiable for computing individual factor scores because it is dispersion matrix data.';
            dlg2=' Please, provide a raw data on Psychological Test Toolbox and repeat the analysis';
            errordlg([dlg1 dlg2],'Psychological Test Toolbox: Scoring Utility');
            
            Forced_ClearData_Callback(hObject, eventdata, handles);
            
            [im,map,alpha_channel]=imread('rojo_t.png','png');

            f=imshow(im,'parent',handles.axes1);
            set(f,'AlphaData',alpha_channel);
            set(handles.import_new_data,'enable','off');
            return;
        end;
        
        %Coses que necessitem per donar les puntuacions dels subjectes: R
        %(o Rp), P i PHI
        % At least, data.R, data.SS or data.Rp are needed
        
        switch data.Matrix
            case 1 %covariance matrix, we need data.SS
                check_exist=isfield(data,'SS');
                if check_exist==1
                    check_matrix=isempty(data.SS);
                end;
            case 2 %Pearson matrix, we need data.R
                check_exist=isfield(data,'R');
                if check_exist==1
                    check_matrix=isempty(data.R);
                end;
            case 3 %Polychoric matrix, we need data.Rp
                check_exist=isfield(data,'Rp');
                if check_exist==1
                    check_matrix=isempty(data.Rp);
                end;
        end;
        
        everything_ok=0;
        if isfield(data,'PHI') && isfield(data,'P') && check_exist==1
            % All the requiered fiels exists, let's check if they have any
            % data
            
            if isempty(data.PHI) || isempty(data.P) || check_matrix==1
                errordlg('At least one of the matrices requiered for the correction contains empty data','Psychological Test Toolbox: Scoring Utility');
                
                Forced_ClearData_Callback(hObject, eventdata, handles);
                
                [im,map,alpha_channel]=imread('rojo_t.png','png');

                f=imshow(im,'parent',handles.axes1);
                set(f,'AlphaData',alpha_channel);
                set(handles.import_new_data,'enable','off');
            else
                everything_ok=1;
            end;
        else
            errordlg('At least one of the matrices requiered for the correction do not exist on data structure','Psychological Test Toolbox: Scoring Utility');
            
            Forced_ClearData_Callback(hObject, eventdata, handles);
            
            [im,map,alpha_channel]=imread('rojo_t.png','png');

            f=imshow(im,'parent',handles.axes1);
            set(f,'AlphaData',alpha_channel);
            set(handles.import_new_data,'enable','off');
        end;
        
    end;
    
    tmp1={};
    set(handles.ModelOutput,'string',tmp1);
    set(handles.ModelOutput,'value',1);
    set(handles.ModelOutput_latex,'string',tmp1);
    set(handles.ModelOutput_latex,'value',1);
    set(handles.ModelOutput_rtf,'string',tmp1);
    set(handles.ModelOutput_rtf,'value',1);
 
    [im,map,alpha_channel]=imread('verde_t.png','png');

    f=imshow(im,'parent',handles.axes1);
    set(f,'AlphaData',alpha_channel);

    set(handles.import_new_data,'enable','on');
    set(handles.new_data_string,'string',' ');
    set(handles.panel3_tab2,'visible','on');
    data.X_new=[];
    data.N_new=[];    
    data.name_new=[];
    data.path_new=[];
%     set(handles.axes2,'visible','off');
%     set(get(handles.axes2,'children'),'visible','off');
    set(handles.compute,'enable','off');
    
    ver='';
    for i=1:3
        num=code_version(i);
        if i==1
            ver=sprintf('%s.',num);
        else
            ver=[ver num];
        end;
    end;
    
    buff_msg{1}='Successful loading!';
    buff_msg{2}=sprintf('Data generated from Psychological Test Toolbox v%s',ver);
    buff_msg{3}=sprintf('Analysis date: %s',data.actual_date);
    msgbox(buff_msg,'Psychological Test Toolbox: Scoring Utility');
    
    [f1,f2]=size(data.X);
    buff_cell=cell(20,f2);
    buff_numeric={};
    for i=1:f2
        buff_numeric=[buff_numeric 'numeric'];
    end;
        
    set(handles.data_table,'visible','on','Data',buff_cell);
    set(handles.data_table,'ColumnFormat',buff_numeric);
    set(handles.provide,'visible','on');
    set(handles.factor_labels,'visible','on');
    
    Type_new_data(gcf, eventdata, handles , 1)
    set(handles.new_data_string,'string','');
    
    setappdata(0,'data',data);
    
    
return;

% function converttonum(hObject, callbackdata)
%     
% %     str=str2double(callbackdata.EditData);
% %     r = callbackdata.Indices(1);
% %     c = callbackdata.Indices(2);
% %     
% %     if isnan(str)==0
% %         numval = eval(callbackdata.EditData);
% %         hObject.Data{r,c} = numval; 
% %     else
% %         hObject.Data{r,c} = NaN; 
% %     end;
%  
% return;

function Import_new_data_Callback (hObject,eventdata,handles)

    [filename1, pathname1] = uigetfile({'*.dat';'*.txt';'*.mat';'*.xls';'*.xlsx';'*.*'},'Psychological Test Toolbox: Scoring Utility');
    
    if isequal(filename1,0)||isequal(pathname1,0)
        return;
    else
        a=uiimport([pathname1 filename1]);
        if isempty(a)
            return;
        end;
        %load data
        data=getappdata(0,'data');
          
        [tmp1,m]=size(filename1);
        campana=0;variable='';
        for i=1:m
            if filename1(i) == '.'
                campana = 1;
            end;
            if campana == 1
                break
            else
                if filename1(i) == ' '
                else
                    variable = [variable filename1(i)];
                end; 
            end;
        end;

            names=fieldnames(a);
            [f1,f2]=size(names); %comprovem si ha generat diverses estructures
            if f1>1 
                if f1>1 && f1<4 %si ha carregat les etiquetes, suggerim si les vol utilitzar
                    X1=a.data;
                else %si ha generat moltes estructures, ha carregat vectors amb cada item
                    X1=[];
                    for i=1:f1
                        eval(['X1 = [X1 a.' char(names(i)) ']']);
                    end;
                end;
            else
                eval(['X1 = a.' variable]);
            end;

       [f1,f2]=size(X1);
       tmp={};
       % Check if it's a matrix
        if f2 < 2 
            errordlg('The variable must be a matrix','Psychological Test Toolbox: Scoring Utility','Error');
            X1=[];
            return;
        end;
        if f1 < 2 
            errordlg('The variable must be a matrix','Psychological Test Toolbox: Scoring Utility','Error');
            X1=[];
            return;
        end;
        
        % Check if contains NaN
        [row, col] = find(isnan(X1));
        if isempty(row)
        else
            dlg1='The file contains some NaN values. Please, replace that values for one specific value';
            dlg2='(for example 999) and then reupload the file';
            errordlg([dlg1 dlg2],'Psychological Test Toolbox: Scoring Utility');
            X1=[];
            return;
        end;
        
        %Check if the new data is consistent with the previous data
        if f2<data.n
            errordlg('The new data have less variables than the original','Psychological Test Toolbox: Scoring Utility','Error');
            X1=[];
            return;
        end;
        
        if f2>data.n
            errordlg('The new data have more variables than the original','Psychological Test Toolbox: Scoring Utility','Error');
            X1=[];
            return;
        end;
    end;
    
    data.X_new=X1;
    [f1,f2]=size(X1);
    data.N_new=f1;
    data.Xa_new=X1(:,data.itemsa);
    data.name_new=filename1;
    data.path_new=[pathname1 filename1];
    setappdata(0,'data',data);
    
    [im,map,alpha_channel]=imread('verde_t.png','png');
    
    set(handles.new_data_string,'string',[pathname1 filename1]);
    
    tmp={};
    set(handles.ModelOutput,'string',tmp);
    set(handles.ModelOutput_latex,'string',tmp);
    set(handles.ModelOutput_rtf,'string',tmp);
    
    set(handles.ButtonLaunchOutput,'enable','off');
    set(handles.ButtonSalvarOutput,'enable','off');
    set(handles.compute,'enable','on');
    
return;

function Compute_Callback (hObject,eventdata,handles)
    
    %STARTING ANALYSIS
    set(gcbf,'Pointer','watch');
    
    %Start new figure with an icon meanwhile other waitbars as the 
    %polychoric computing or factor scores are not initialized
    %new figure
    finestra.N2=250;
    finestra.M2=100;
    pantalla=get(0,'ScreenSize');
    finestra.coordenades=[(pantalla(3)/2)-(finestra.N2/2)  (pantalla(4)/2)-(finestra.M2/2) finestra.N2 finestra.M2];
    handles.fig_scoring = figure('Units','Pixels',...
    'color' , [0.941 0.941 0.941],...
    'Position',finestra.coordenades);
    set(handles.fig_scoring, 'MenuBar','none','Name','Psychological Test Toolbox','Toolbar','none','NumberTitle','off','resize','off');
    set(handles.fig_scoring,'Pointer','watch');
    
    jObj = waiting(handles);
    
    data=getappdata(0,'data');  
    
    checking_DS=data.checking_DS;
    checking_AQ=data.checking_AQ;
    
    
    if isfield(data,'missings_on_new')==0
        data.missings_on_new=0;
        setappdata(0,'data',data);
    end;
    
    if data.missings_on_new==1
        %The missing value has been already selected, no action
    else
        %Ask if the new dataset contains missings values defined by a specific
        %value (for example, 999)

        answ=questdlg('The provided data contains missings values?','Psychological Test Toolbox: Scoring Utility','Yes','No','No');
        waitfor(answ);

        switch answ
            case 'No'
                data.missings_on_new=0;
            case 'Yes'

                N2=350;
                M2=100;
                pantalla=get(0,'ScreenSize');
                coordenades=[(pantalla(3)/2)-(N2/2)  (pantalla(4)/2)-(M2/2) N2 M2];
                handles.fig_miss = figure('Units','Pixels',...
                'color' , [0.941 0.941 0.941],...
                'Position',coordenades);
                set(handles.fig_miss, 'MenuBar','none','Name','Psychological Test Toolbox: Scoring Utility','Toolbar','none','NumberTitle','off','resize','off');

                handles.text_miss_value=uicontrol(handles.fig_miss,'Style','text',...
                    'Units','pixels',...
                    'position',[10 60 220 20],...
                    'FontSize',12,...
                    'fontname',char(data.font),...
                    'HorizontalAlignment','left',...
                    'BackgroundColor', [.941 .941 .941],...
                    'String','Defined missing value:');

                 %QUADRE EDITABLE DEL VALOR DELS MISSING
                handles.missingvalue= uicontrol(handles.fig_miss,'Style','edit',...
                    'Units','pixels',...
                    'position',[220 60 120 25],...
                    'FontSize',13,...
                    'fontname',char(data.font),...
                    'TooltipString','Define wich value indicate the presence of a missing value',...
                    'max',0,...  
                    'BackgroundColor',[1 1 1],...
                    'Visible','on',...
                    'ForegroundColor',[0 0 0],...  
                    'HorizontalAlignment','right',...
                    'BackgroundColor', [1 1 1],...
                    'String',data.missings_value);

                %CANCEL button
                handles.cancel= uicontrol(handles.fig_miss,'Style','Pushbutton',...
                    'Units','pixels',...
                    'position',[120 10 100 35],...
                    'Fontname',char(data.font),...
                    'Fontsize',13,...
                    'ForegroundColor',[.2 .2 .2],...
                    'BackgroundColor',[.911 .911 .911],...
                    'String','Cancel',...
                    'Callback',{@Cancel_Callback});

                %OK button
                handles.ok= uicontrol(handles.fig_miss,'Style','Pushbutton',...
                    'Units','pixels',...
                    'position',[240 10 100 35],...
                    'Fontname',char(data.font),...
                    'Fontsize',13,...
                    'ForegroundColor',[.2 .2 .2],...
                    'BackgroundColor',[.911 .911 .911],...
                    'String','OK',...
                    'Callback',{@Ok_Callback, handles});
                
                waitfor(handles.fig_miss);

        end;
    end;
    
    data=getappdata(0,'data');
                
    
    if data.missings_on_new==1 %The new data contains missing values
    
%     if data.missings_on==1 % There were missing values in the original analysis

        X_miss = data.X_new == data.missings_value_new ;
        X_missa = data.X_new(:,data.inclosos) == data.missings_value_new ;
        data.Xa_new=data.X_new(:,data.inclosos);
        
%         if ~any(X_miss)==1 %there are no missing value data
%             data.missings_on_new=0;
%         else     
%             data.missings_on_new=1;

            %Ara la matriu X_miss esta formada per 0 si la puntuacio no es
            %missing i per 1 si si que es valor missing

            [f1,f2]=size(X_miss);
            X_sensemiss=[];
            X_sensemissa=[];
            u=0;

            for i=1:f1
                a=any(X_miss(i,:) == 1);
                if a==1
                    u=u+1;
                    %No fem res, ja que aquest individu te algun missing
                    %value
                else
                    X_sensemiss(i-u,:) = data.X_new(i,:);
                end;
            end;
            u=0;
            for i=1:f1
                a=any(X_missa(i,:) == 1);
                if a==1
                    u=u+1;
                    %No fem res, ja que aquest individu te algun missing
                    %value
                else
                    X_sensemissa(i-u,:) = data.Xa_new(i,:);
                end;
            end;

            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            % THE SAME FOR THE ORIGINAL SAMPLE
            
            if data.missings_on==0 %if the original sample does
                %not contains missings
                X_miss_o=data.X == data.missings_value_new ;
                X_missa_o=data.X(:,data.inclosos) == data.missings_value_new;
                X_sensemiss_o=[];
                X_sensemissa_o=[];
                f1=0;
            else

                X_miss_o = data.X == data.missings_value ;
                X_missa_o = data.X(:,data.inclosos) == data.missings_value ;

                [f1,f2]=size(X_miss_o);
                X_sensemiss_o=[];
                X_sensemissa_o=[];
                u=0;

                for i=1:f1
                    a=any(X_miss_o(i,:) == 1);
                    if a==1
                        u=u+1;
                        %No fem res, ja que aquest individu te algun missing
                        %value
                    else
                        X_sensemiss_o(i-u,:) = data.X(i,:);
                    end;
                end;
                u=0;
                for i=1:f1
                    a=any(X_missa_o(i,:) == 1);
                    if a==1
                        u=u+1;
                        %No fem res, ja que aquest individu te algun missing
                        %value
                    else
                        X_sensemissa_o(i-u,:) = data.Xa(i,:);
                    end;
                end;
            
            end;

            %%%%%%%%%%%%%%%%%%%%%%%%%

            [f1,f2]=size(X_sensemiss);
            data.X_sensemiss_new=X_sensemiss;
            data.X_sensemissa_new=X_sensemissa;
            data.N_sensemiss_new=f1;

    %         [f1,f2]=size(data.X); %la matriu amb tots els participants i items
    %         data.N_original=f1;

            setappdata(0,'data',data);


            % NUMBER OF MULTIPLE IMPUTATIONS
            k = 5;

            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %  ANALYSIS OF DATA WHERE MISSING DATA IS PRESENT
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

            % Multiple imputation: To produce k samples with imputate data
            % WE WILL USE THE ORIGINAL SAMPLE FOR FINDING NEIGHBOURS,
            % putting the new values at the end
            Xm = HotDeck_imputation([data.Xa;data.Xa_new],[X_missa_o;X_missa],k);
            data.Xm_new=Xm((data.N+1):(data.N+data.N_new),:,:);
            
            if data.missings_on==1
                Xm_all = HotDeck_imputation([data.X;data.Xa_new],[X_miss_o;X_miss],k);
                data.Xm_all_new=Xm_all((data.N+1):(data.N+data.N_new),:,:);
            end;
%         end;
    end;    
    
    setappdata(0,'data',data);

    if data.missings_on_new==1 % If there are missing values, the process is 
        %more sofisticated, because we have to compute the factor scores
        %for each sample and do the average
        
        [th,th_li,th_ls,se,reli]=Compute_with_missings;
        
    else
        
        [th,th_li,th_ls,se,reli]=Compute_without_missings;
        
    end;
    
    data.th=th;
    data.th_li=th_li;
    data.th_ls=th_ls;
    data.se=se;
    data.reli=reli;
    
    tmp1={};
    set(handles.ModelOutput,'string',tmp1);
    set(handles.ModelOutput,'value',1);
    set(handles.ModelOutput_latex,'string',tmp1);
    set(handles.ModelOutput_latex,'value',1);
    set(handles.ModelOutput_rtf,'string',tmp1);
    set(handles.ModelOutput_rtf,'value',1);
 
    setappdata(0,'data',data);
    
    % Printing
%     Print_Header(handles.ModelOutput,handles.ModelOutput_latex,handles.ModelOutput_rtf);
    Print_Factor_Analysis(handles.ModelOutput,handles.ModelOutput_latex,handles.ModelOutput_rtf);
    PrintFactorScores(data,handles.ModelOutput,handles.ModelOutput_latex,handles.ModelOutput_rtf);
    
    set(handles.ButtonLaunchOutput,'enable','on');
    set(handles.ButtonSalvarOutput,'enable','on');
    set(handles.ModelOutputDecrementa,'enable','on','visible','on');
    set(handles.ModelOutputIncrementa,'enable','on','visible','on');
    set(handles.save_latex,'enable','on');
    set(handles.save_rtf,'enable','on');
    set(handles.save_text,'enable','on');
    
    jObj.setBusyText('Analysis complete!');jObj.stop; 
        
    if ishandle(handles.fig_scoring)
        set(handles.fig_scoring,'Pointer','arrow')
        figure(handles.fig_scoring);
        t = timer;
        t.StartDelay = 5;
        t.TimerFcn = @(myTimerObj, thisEvent)close(handles.fig_scoring);
        start(t);
    end;
    
    set(gcbf,'Pointer','arrow');
    
return;

function [th,th_li,th_ls,se,reli]=Compute_with_missings

    data=getappdata(0,'data');

    Xm=data.Xm_new;
    N=data.N_new;
    [~,r]=size(data.P);
    k=5;
    corr=data.Matrix;
    checking_AQ=data.checking_AQ;
    checking_DS=data.checking_DS;


    % FACTOR SCORES FOR EACH SAMPLE 
    Fm=zeros(N,r,k);
    Fm_ls=zeros(N,r,k);
    Fm_li=zeros(N,r,k);
    if corr==3
        Sem=zeros(N,r,k);
        relim=zeros(N,r,k);
        Se=zeros(N,r);
        reli=zeros(N,r);
    else
        Sem=zeros(r,r,k);
        relim=zeros(r,1,k);
        Se=zeros(r,r);
        reli=zeros(r,1);
    end;
    F=zeros(N,r);
    F_li=zeros(N,r);
    F_ls=zeros(N,r);


    Fint=zeros(N,2,r);

    %%%% FACTOR SCORES AS AVERAGE
    % save tmp

    if corr==3 %GLOBAL WAITBAR FOR COMPUTING FACTOR SCORES
        tmp={};
        tmp{1}=('Computing factor scores, this operation can take a while, depending of');
        tmp{2}=sprintf('the number of items and imputations (5 by default) ... (Actual imputation = 1 / %.0f  )',k);
        BarCount = 0;
        bar0 = waitbar(BarCount,tmp);
        pos_1=get(bar0,'position');
        pos_2=[pos_1(1) pos_1(2)+(1.5*pos_1(4)) pos_1(3) pos_1(4)];
        set(bar0,'position',pos_2,'doublebuffer','on');
        TicPrint = tic;
        TotalLines=k;
    end;

    PHI=data.PHI;
    P=data.P;
    [~,m]=size(data.Xa_new);
    G=data.G;
    [~,r_c]=size(data.P);
    r_c=r_c-checking_DS-checking_AQ;
    PHIt=PHI((checking_DS+checking_AQ+1):(checking_DS+checking_AQ+r_c),(checking_DS+checking_AQ+1):(checking_DS+checking_AQ+r_c));

    for ik=1:k

        switch corr
            case 1     %Variance
                [Fi,Fi_li,Fi_ls,Se2,reli2] = eap_continuous_obli_corrector(Xm(:,:,ik), P, PHI);
            case 2     %Pearson
                [Fi,Fi_li,Fi_ls,Se2,reli2] = eap_continuous_obli_corrector(Xm(:,:,ik), P, PHI);
            case 3     %Polychoric
                THRES=[data.thresholds(data.inclosos,:)'; zeros(1,m)];

                 Bi=THRES;
                 sigj_i = sqrt(ones(m,1)-diag(P*PHI*P'));

                 %it has to be done in separate steps:
                m=G(1)+G(2);
                [g1,g2]=size(P);
                if checking_DS==1
                    [Fi_a,Fi_li_a,Fi_ls_a,Se2_a,reli2_a] = reap_grad_obli(Xm(:,:,ik), P(:,1), 1, Bi, sigj_i,1,1);

                    if checking_AQ==1
                        %AC
                        [Fi_b,Fi_li_b,Fi_ls_b,Se2_b,reli2_b] = reap_grad_obli(Xm(:,G(1)+1:m,ik), P(G(1)+1:m,2), 1, Bi(:,G(1)+1:m), sigj_i(G(1)+1:m),1,2);

                        %content
                        [Fi_c,Fi_li_c,Fi_ls_c,Se2_c,reli2_c] = reap_grad_obli(Xm(:,G(1)+1:m,ik), P(G(1)+1:m,3:g2), PHIt, Bi(:,G(1)+1:m), sigj_i(G(1)+1:m),1,3);
                    else
                        %AC (NO)
                        Fi_b=[]; Fi_li_b=[]; Fi_ls_b=[]; Se2_b=[]; reli2_b=[];

                        %content
                        [Fi_c,Fi_li_c,Fi_ls_c,Se2_c,reli2_c] = reap_grad_obli(Xm(:,G(1)+1:m,ik), P(G(1)+1:m,2:g2), PHIt, Bi(:,G(1)+1:m), sigj_i(G(1)+1:m),1,3);
                    end;
                else
                    %SD (no)
                    Fi_a=[]; Fi_li_a=[]; Fi_ls_a=[]; Se2_a=[]; reli2_a=[];
                    if checking_AQ==1
                        [Fi_b,Fi_li_b,Fi_ls_b,Se2_b,reli2_b] = reap_grad_obli(Xm(:,:,ik), P(:,1), 1, Bi, sigj_i,1,2);

                        %content
                        [Fi_c,Fi_li_c,Fi_ls_c,Se2_c,reli2_c] = reap_grad_obli(Xm(:,:,ik), P(:,2:g2), PHIt, Bi, sigj_i,1,3);
                    else
                        %AC (NO)
                        Fi_b=[]; Fi_li_b=[]; Fi_ls_b=[]; Se2_b=[]; reli2_b=[];

                        %content
                        [Fi_c,Fi_li_c,Fi_ls_c,Se2_c,reli2_c] = reap_grad_obli(Xm(:,:,ik), P, PHIt, Bi, sigj_i,1,3);
                    end;

                end;
                Fi=[Fi_a Fi_b Fi_c];
                Fi_li=[Fi_li_a Fi_li_b Fi_li_c];
                Fi_ls=[Fi_ls_a Fi_ls_b Fi_ls_c];
                Se2=[Se2_a Se2_b Se2_c];
                reli2=[reli2_a reli2_b reli2_c];

            otherwise
                [Fi,Fi_li,Fi_ls,Se2,reli2] = eap_continuous_obli_corrector(Xm(:,:,ik), P(:,:,ik), PHI);
        end;
        Fm(:,:,ik)=Fi;
        Fm_li(:,:,ik)=Fi_li;
        Fm_ls(:,:,ik)=Fi_ls;
        Sem(:,:,ik)=Se2;
        relim(:,:,ik)=reli2;


        tmp=sprintf('Factor scores matrix %.0f done!',ik);disp(tmp);
        if corr==3
            if ik==k
                close(bar0);
            else
                BarCount = BarCount + 1; 
                compT = toc(TicPrint);
                compT = compT*(TotalLines-BarCount)/BarCount;
                s_tmp={};
                s_tmp{1}=sprintf('Computing factor scores ... Actual imputation =  %.0f  / %.0f ) ',ik+1,k);
                s_tmp{2}=sprintf('(Remaining time =  %s )',Time2String( compT ));
                waitbar(BarCount/TotalLines,bar0,s_tmp);
            end;
        end;
    end;

    for ik=1:k
        F= F + Fm(:,:,ik);
        F_li= F_li + Fm_li(:,:,ik);
        F_ls= F_ls + Fm_ls(:,:,ik);
        Se= Se + Sem(:,:,ik);
        reli= reli + relim(:,:,ik);
    end;

    th = F / k;
    th_li = F_li / k;
    th_ls = F_ls / k;
    se = Se / k;
    reli = reli / k;

    Fint=zeros(N,2,r);
    for i=1:r
        tmp=[];
        for ik=1:k
            tmp=[tmp Fm(:,i,ik)];
        end;
        Fint(:,1,i)=min(tmp')';
        Fint(:,2,i)=max(tmp')';
    end;

return

function [th,th_li,th_ls,se,reli]=Compute_without_missings
    
    data=getappdata(0,'data');

    P = data.P;
    X = data.X_new(:,data.itemsa);
    PHI=data.PHI;
    checking_DS=data.checking_DS;
    checking_AQ=data.checking_AQ;
    
    
    [th,th_li,th_ls,se,reli] = eap_continuous_obli_corrector(X,P,PHI,data.Matrix);

%    switch data.Matrix
       
       
       
%         %Variance matrix or Pearson
%         case {1,2}
% %             [data.th,~,W] = scores(X, P, PHI);
%             %NOVA FUNCIO
%             [th,th_li,th_ls,se,reli] = eap_continuous_obli_corrector(X,P,PHI);
% 
%         %Polychoric    
%         case 3
%             THRES = data.thresholds(data.itemsa,:);
%             [m,k]=size(THRES);
%             THRES = [THRES zeros(m,1)]';
%             R=data.Rp_all;

%             if isempty(data.A) %quan si vol  DS i/o AQ, fem servir P
% %                 sigj = diag(sqrt( diag(diag(data.Rp - data.P*data.P'))));
%                 sigj = diag(sqrt( diag(diag(data.Rp - P*PHI*P'))));
% 
%             else %quan no vol DS ni AQ, fem servir A
%                 sigj = diag(sqrt( diag(diag(data.Rp - data.A*data.A'))));
%             end;  
            


%             %it has to be done in separate steps:
%             m=data.G(1)+data.G(2);
%             [g1,g2]=size(data.P);
%             PHI_c=data.PHI(checking_DS+checking_AQ+1:g2,checking_DS+checking_AQ+1:g2);
%             if data.checking_DS==1
%                 [th1,th_li1,th_ls1,se1,reli1] = reap_grad_obli(X, P(:,1), 1, THRES, sigj,1,1);
% 
%                 if data.checking_AQ==1
%                     %AC
%                     [th2,th_li2,th_ls2,se2,reli2] = reap_grad_obli(X(:,data.G(1)+1:m), P(data.G(1)+1:m,2), 1, THRES(:,data.G(1)+1:m), sigj(data.G(1)+1:m),1,2);
% 
%                     %content
%                     [th3,th_li3,th_ls3,se3,reli3] = reap_grad_obli(X(:,data.G(1)+1:m), P(data.G(1)+1:m,3:g2), PHI_c, THRES(:,data.G(1)+1:m), sigj(data.G(1)+1:m),1,3);
%                 else
%                     %AC (NO)
%                     th2=[]; th_li2=[]; th_ls2=[]; se2=[]; reli2=[];
% 
%                     %content
%                     [th3,th_li3,th_ls3,se3,reli3] = reap_grad_obli(X(:,data.G(1)+1:m), P(data.G(1)+1:m,2:g2), PHI_c, THRES(:,data.G(1)+1:m), sigj(data.G(1)+1:m),1,3);
%                 end;
%             else
%                 %SD (no)
%                 th1=[]; th_li1=[]; th_ls1=[]; se1=[]; reli1=[];
%                 if data.checking_AQ==1
%                     [th2,th_li2,th_ls2,se2,reli2] = reap_grad_obli(X, P(:,1), 1, THRES, sigj,1,2);
% 
%                     %content
%                     [th3,th_li3,th_ls3,se3,reli3] = reap_grad_obli(X, P(:,2:g2), PHI_c, THRES, sigj,1,3);
%                 else
%                     %AC (NO)
%                     th2=[]; th_li2=[]; th_ls2=[]; se2=[]; reli2=[];
% 
%                     %content
%                     [th3,th_li3,th_ls3,se3,reli3] = reap_grad_obli(X, P, PHI_c, THRES, sigj,1,3);
%                 end;
% 
%             end;
%             th=[th1 th2 th3];
%             th_li=[th_li1 th_li2 th_li3];
%             th_ls=[th_ls1 th_ls2 th_ls3];
%             se=[se1 se2 se3];
%             reli=[reli1 reli2 reli3];

%    end;

return;

function Provide_Callback (hObject,eventdata,handles)

    data=getappdata(0,'data');
    
    buff=get(handles.data_table,'Data');
    
%   OPTION B: WORKING WITH CELLS
    emptyCells = cellfun(@isempty,buff);
    buff(emptyCells)={-1};
    buff=cell2mat(buff);
    
%     OPTION A: WORKING WITH ONLY NUMERICAL VALUES (easier to perform, and
%     quicker but less appealing)

    [row,col]=find(buff~=-1);
    
    [f1,f2]=size(buff);
    
    valid_data_all=[];
    h=1; empty_rows={};
    g=1; valid_rows=[];
    for i=1:f1
        buff_empty=find(buff(i,:)~=-1);
        if isempty(buff_empty)
            empty_rows{h}=i;
            h=h+1;
        else
            valid_rows(g)=i;
            g=g+1;
        end;
    end;
    
    max_valid_row=max(valid_rows);
    
    n_rows=1:max_valid_row;
    
    valid_data_all=buff(n_rows,:);
    
    valid_data=buff(unique(row),:);
    if isempty(valid_data)
        errordlg('At least one new case is requiered','Psychological Test Toolbox: Scoring Utility');
        return;
    end;
    
    n_valid=1;
    k=0;
    valid_data_real=[];
     %%%%%%%% REFORMULAR UTILITZANT valid_data_all, que conte totes les
     %%%%%%%% files fins que totes son -1
     for i=1:max_valid_row
         
         buff_row=valid_data_all(i,:);
         buff_nan=find(isnan(buff_row));
%          buff_nan=find(buff2==1); %NaN cases
         [~,n_nan]=size(buff_nan);
         
         buff_empty=find(buff_row==-1);
         [~,n_empty]=size(buff_empty);
         
         if (n_nan+n_empty)==data.n
             % All the values of the row are empty or NaN
             buff_empty_msg{1}=sprintf('Apparently, the row number %.f only contains empty and NaN values.',i);
             buff_empty_msg{2}=sprintf('This row will be dropped.');
             fig_warn=warndlg(buff_empty_msg,'Psychological Test Toolbox: Scoring Utility');
             waitfor(fig_warn);
%              valid_data_real=valid_data_all(~ismember(1:size(valid_data_all,1), i), :);
             k=k+1;
         
         else
             if n_nan>0 %There are some NaN values

                buff_nan_msg{1}=sprintf('There are some NaN values, the first one is located on row number %.f.',min(unique(row)));
                buff_nan_msg{2}='If it is a missing value, please replace it with the same value that used on Psychological Test Toolbox.';
                fig_error=errordlg(buff_nan_msg,'Psychological Test Toolbox: Scoring Utility');
                waitfor(fig_error);
                return;

             elseif n_nan==0 %There are no NaN values in the row

                 if n_empty==0 % No empty cells, everything ok
                     valid_data_real(n_valid,:)=buff_row;
                     n_valid=n_valid+1;
                 else % No NaN values but some empty cells
                     %Let's check if it was defined a missing value in the original data
                     if isempty(data.missings_value)

                        buff_und{1}=sprintf('There are some undefined values, the first one is located on row number %.f.',i);
                        buff_und{2}='If it is a missing value, please replace it with a specific value (e.g. 999)';
                        errordlg(buff_und,'Psychological Test Toolbox: Scoring Utility');
                        return;
                     else
                        buff_und{1}=sprintf('There are some undefined values, the first one is located on row number %.f.',i);
                        buff_und{2}='If it is a missing value, we can replace it automatically for the value defined in the original analysis.';
                        buff_und{3}='Do you want to perform this conversion for all undefined values?';
                        answ=questdlg(buff_und,'Psychological Test Toolbox: Scoring Utility');
                        waitfor(answ);

                        switch answ
                            case 'Yes'
                                data.missings_value_new=data.missings_value;
                                buff_row(buff_row==-1)=data.missings_value_new;
                                [row,col]=find(buff_row==data.missings_value_new);
                                OldData=get(handles.data_table,'Data');
                                NewData=OldData;

                                [f1,f2]=size(row);                    
                                for j=1:f2
                                    NewData(i,col(j))=num2cell(data.missings_value_new);
                                end;
                                set(handles.data_table,'Data',NewData);
%                                 buff_row=NewData(i,:);
                                valid_data_real(i-k,:)=buff_row;
                            case 'No'
                                return;
                            case 'Cancel'
                                return;
                        end;
                     end;
                 end;
             end;
         end;
     end;
    
    data.missings_on_new=0;
    if isempty(data.missings_value)==0
        buff_missings = find( valid_data_real == data.missings_value );
        
        if isempty(buff_missings)==0 %there are some values corresponding with the missing value determined by the user
            buff_miss{1}=sprintf('The provided data include some values defined as missing values in the original analysis (%.f).',data.missings_value);
            buff_miss{2}='If it is correct, the program will select these values and treat them as missing values.';
            buff_miss{3}='Do you want to continue?';
            answ=questdlg(buff_miss,'Psychological Test Toolbox: Scoring Utility');
            waitfor(answ);
            
            switch answ
                case 'Yes'
                    data.missings_on_new=1;
                    data.missings_value_new=data.missings_value;
                case 'No'
                    return;
                case 'Cancel'
                    return;
            end;
        end;
        
    end;
    
    [f1,f2]=size(valid_data_real);
    
    buff1{1}=sprintf('A total number of %.f new cases will be provided. Is this information correct?',f1);
    answ=questdlg(buff1,'Psychological Test Toolbox: Scoring Utility','Yes','No','Yes');
    waitfor(answ);
    
    switch answ
        case 'Yes'
            data.X_new=valid_data_real;
            data.Xa_new=valid_data_real(:,data.itemsa);
            [f1,f2]=size(valid_data_real);
            data.N_new=f1;
            set(handles.Participants_number,'string',num2str(f1));
        case 'No'
            if isempty(data.missings_value)==0
                set(handles.data_table,'Data',OldData);
            end;
            return;
    end;

    setappdata(0,'data',data);
    
    tmp={};
    set(handles.ModelOutput,'string',tmp);
    set(handles.ModelOutput_latex,'string',tmp);
    set(handles.ModelOutput_rtf,'string',tmp);
    
    set(handles.ButtonLaunchOutput,'enable','off');
    set(handles.ButtonSalvarOutput,'enable','off');
    set(handles.compute,'enable','on');
    
    set(handles.hTabGroup,'Selectedtab',handles.tab(2));
    

return;

function Print_Header(Output,Output2,Output3)
    
    data=getappdata(0,'data'); 
    
    A=data.X;
    
    %%%%%%%%%%%%%% LATEX %%%%%%%%%%%%%%    
    
    MyPrint(Output2,'% LaTeX Report based on:');
    MyPrint(Output2,'% Example: Project Report');
    MyPrint(Output2,'% Source: http://www.howtotex.com');
    MyPrint(Output2,'\documentclass[paper=a4, fontsize=11pt]{scrartcl}');
    MyPrint(Output2,'\usepackage{float}');
    MyPrint(Output2,'\usepackage[T1]{fontenc}');
    MyPrint(Output2,'\usepackage{fourier}');
    MyPrint(Output2,'\usepackage[english]{babel}');
    MyPrint(Output2,'\usepackage[protrusion=true,expansion=true]{microtype}');
    MyPrint(Output2,'\usepackage[pdftex]{graphicx}');
    MyPrint(Output2,'\usepackage{url}');
    MyPrint(Output2,'\usepackage{longtable}');
    MyPrint(Output2,'\usepackage{pgfplots}');
    MyPrint(Output2,'\usepackage{siunitx}');
    MyPrint(Output2,'\usepackage{booktabs}');
    MyPrint(Output2,'\usepackage{array}');
    MyPrint(Output2,'\usepackage[section]{placeins}');
    MyPrint(Output2,'%%% Custom sectioning');
    MyPrint(Output2,'\usepackage{sectsty}');
    MyPrint(Output2,'\allsectionsfont{\centering \normalfont\scshape}');
    MyPrint(Output2,'%%% Custom headers/footers (fancyhdr package)');
    MyPrint(Output2,'\usepackage{fancyhdr}');
    MyPrint(Output2,'\pagestyle{fancyplain}');
    MyPrint(Output2,'\fancyhead{}');
    MyPrint(Output2,'\fancyfoot[L]{}');
    MyPrint(Output2,'\fancyfoot[C]{}');
    MyPrint(Output2,'\fancyfoot[R]{\thepage}	');
    MyPrint(Output2,'\renewcommand{\headrulewidth}{0pt}');
    MyPrint(Output2,'\renewcommand{\footrulewidth}{0pt}');
    MyPrint(Output2,'\setlength{\headheight}{13.6pt}');
    MyPrint(Output2,'%%% Maketitle metadata');
    MyPrint(Output2,'\newcommand{\horrule}[1]{\rule{\linewidth}{#1}} 	% Horizontal rule');
    MyPrint(Output2,'\title{');
    MyPrint(Output2,'		\usefont{OT1}{bch}{b}{n}');
    MyPrint(Output2,'		\normalfont \normalsize \textsc{Universitat Rovira i Virgili} \\ [5pt]');
    MyPrint(Output2,'		\horrule{0.5pt} \\[0.4cm]');
    MyPrint(Output2,'		\huge Psychological Test Toolbox Report \\');
    MyPrint(Output2,'		\horrule{2pt} \\[1pt]');
    MyPrint(Output2,'}');
    MyPrint(Output2,'\author{');
    MyPrint(Output2,'	\normalfont 		\normalsize');
    MyPrint(Output2,'	David Navarro-Gonzalez, Andreu Vigil-Colet , Pere Joan Ferrando \& Urbano Lorenzo-Seva\\[-3pt]		\normalsize');
    MyPrint(Output2,'        \today');
    MyPrint(Output2,'}');
    MyPrint(Output2,'\date{}');
    MyPrint(Output2,' ');
    MyPrint(Output2,'%%% Begin document');
    
    MyPrint(Output2,'\begin{document}');
    MyPrint(Output2,'\maketitle');
    
    MyPrint(Output2,'\section{Descriptives}');
    MyPrint(Output2,'\begin{table}[!htb]');
    MyPrint(Output2,'\caption{Data details}');
    MyPrint(Output2,'\label{taula:descriptives}');
    MyPrint(Output2,'\centering');
    MyPrint(Output2,'\begin{tabular}{l l} \toprule');
    buff2 = '\\';ve='\v'; buff0='\textbf';
    [f1,f2]=size(data.path);
    if f2>45 %if path is too long
        slashposition=findstr(data.path,'\');
        if isempty(slashposition)
            slashposition=findstr(data.path,'/');
        end;
        [g1,g2]=size(slashposition);
        for i=1:g2
            lastslash=slashposition(i);
            if lastslash<45
               %continue finding
            else
                lastslash=slashposition(i-1);
                break;
            end;
        end;
        buff = sprintf('{File path}: & %serb$%s$ ',ve,data.path(1:lastslash));
        MyPrint(Output2,[buff0 buff buff2]);
        path2=data.path(lastslash+1:f2);
        [g1,g2]=size(path2);
        if g2>45 %again
            slashposition=findstr(path2,'\');
            if isempty(slashposition)
                slashposition=findstr(path2,'/');
            end;
            [h1,h2]=size(slashposition);
            for i=1:h2
                lastslash=slashposition(i);
                if lastslash<45
                   %continue finding
                else
                    lastslash=slashposition(i-1);
                    break;
                end;
            end;
            buff = sprintf('~ & %serb$%s$ ',ve,path2(1:lastslash));
            MyPrint(Output2,[buff buff2]);
            buff = sprintf('~ & %serb$%s$ ',ve,path2(lastslash+1:g2));
            MyPrint(Output2,[buff buff2]);
            
        else
            buff = sprintf('~ & %serb$%s$ ',ve,path2);
            MyPrint(Output2,[buff buff2]);
        end;
        
    end;
%     end;
    if data.matrix_user_on==0
        buff = sprintf('{Number of participants}: & %5.0f ',data.N_original);
        MyPrint(Output2,[buff0 buff buff2]);
    end;
    if data.missings_on==1
        buff = sprintf('{Number of participants without missing data}: & %5.0f',data.N_sensemiss); MyPrint(Output2, [buff0 buff buff2]);
    end;
    buff = sprintf('{Number of items}: & %5.0f ',data.n);
    MyPrint(Output2,[buff0 buff buff2]);
    [tmp, m_t]=size(A);
    [m,tmp]=size(char(data.inclosos));
    if tmp > m
        m=tmp;
    end;
    if m_t == m
       MyPrint(Output2,'\textbf{Items included in the analysis}: & ALL \\');
                      
    else
        buff = '\textbf{Items included in the analysis}: & ';
        buff01='';
        for i=1:m-1
            buff1=sprintf('%.0f, ',data.inclosos(i));
            buff01 = [buff01 buff1];
            [g1,g2]=size(buff01);
            if g2>67
                MyPrint(Output2,[buff buff01 buff2]);
                buff='~ & ';
                buff01='';
            end;
        end;
        buff1=sprintf('%.0f',data.inclosos(m));
        buff = [buff buff01 buff1 buff2];
        MyPrint(Output2,buff );
        buff = '\textbf{Items excluded in the analysis}: & ';
        h=1;
        for i=1:m_t
            in=0;
            for j=1:m
                if data.inclosos(j) == i
                    in=1;
                    break;
                end;
            end;
            if in == 0
               if h==1
                  buff1=sprintf('%.0f',i);
               else
                  buff1=sprintf(', %.0f',i);
               end;
               buff = [buff buff1];
               h=2;
            end;
        end;
        MyPrint(Output2,[buff buff2]);
    end
    if data.matrix_user_on==1
        MyPrint(Output2,'\textbf{Dispersion Matrix}: & User Defined \\');
    else
        if data.Matrix==1
            MyPrint(Output2,'\textbf{Dispersion Matrix}: & Covariance Matrix \\');
        elseif data.Matrix==2
            MyPrint(Output2,'\textbf{Dispersion Matrix}: & Pearson Correlations \\');
        elseif data.Matrix==3
            MyPrint(Output2,'\textbf{Dispersion Matrix}: & Polychoric Correlations \\');
        end;
    end;
    
    %If we are doing factor analysis
    if data.forced_descriptives==1
        buff = '{Method for factor extraction}: & Unweighted Least Squares (ULS)';
        MyPrint(Output2, [buff0 buff buff2]);
        buff= ' ~ & (ten Berge and Kiers, 1991)';
        MyPrint(Output2, [buff buff2]);
        switch data.Rotation
            case 1 %Orthogonal
                buff = '{Rotation Method}: & Varimax';
                MyPrint(Output2, [buff0 buff buff2]);
            case 2 %Oblicque
                buff = '{Rotation Method}: & Promin (Lorenzo-Seva, 1999)';
                MyPrint(Output2, [buff0 buff buff2]);
            case 3
                buff = '{Rotation Method}: & Semi-specified oblique Procrustes rotation';
                MyPrint(Output2, [buff0 buff buff2]);
                buff = '~ & (Browne, 1972b)';
                MyPrint(Output2, [buff buff2]);
            case 4
                buff = '{Rotation Method}: & Semi-specified orthogonal Procrustes rotation';
                MyPrint(Output2, [buff0 buff buff2]);
                buff = '~ & (Browne, 1972a)';
                MyPrint(Output2, [buff buff2]);
        end;
    end;
    
    buff1=clock;
    c=fix(buff1);
    month={};
    month{1}='January';month{2}='February';month{3}='March';month{4}='April';month{5}='May';month{6}='June';
    month{7}='July';month{8}='August';month{9}='September';month{10}='October';month{11}='November';month{12}='December';
    actual_month=month{c(2)};
    %corrected minutes
    if c(5)<10
        buff = sprintf('{Analysis date}: & %.0f:0%.0f, %.0f-%s-%.0f',c(4),c(5),c(3),actual_month,c(1));
    else
        buff = sprintf('{Analysis date}: & %.0f:%.0f, %.0f-%s-%.0f',c(4),c(5),c(3),actual_month,c(1));
    end;
    MyPrint(Output2, [buff0 buff buff2]);
    
    MyPrint(Output2,'\bottomrule');
    MyPrint(Output2,'\end{tabular}');
    MyPrint(Output2,'\end{table}');
    
    %%%%%%%%%%%%%% TEXT %%%%%%%%%%%%%%
    
    MyPrint(Output,' ');
    MyPrint(Output,'DETAILS OF ANALYSIS');
    MyPrint(Output,' ');
    
%     buff = sprintf('Matrix analized                             : %s',data.name); MyPrint(Output, buff);
    buff = sprintf('File path                                   : %s',data.path); MyPrint(Output, buff);
    if data.matrix_user_on==0
        buff = sprintf('Number of participants                      : %5.0f',data.N_original); MyPrint(Output, buff);
    end;
    if data.missings_on==1
        buff = sprintf('Number of participants without missing data : %5.0f',data.N_sensemiss); MyPrint(Output, buff);
    end;
    buff = sprintf('Number of items                             : %5.0f',data.n); MyPrint(Output, buff);
    
    [tmp, m_t]=size(A);
    [m,tmp]=size(char(data.inclosos));
    if tmp > m
        m=tmp;
    end;
    if m_t == m
       MyPrint(Output,'Items included in the analysis              : ALL');
                      
    else
        buff = 'Items included in the analysis              : ';
        for i=1:m-1
            buff1=sprintf('%.0f, ',data.inclosos(i));
            buff = [buff buff1];
        end;
        buff1=sprintf('%.0f',data.inclosos(m));
        buff = [buff buff1];
        MyPrint(Output,buff);
        buff = 'Items excluded in the analysis              : ';
        
        h=1;
        for i=1:m_t
            in=0;
            for j=1:m
                if data.inclosos(j) == i
                    in=1;
                    break;
                end;
            end;
            if in == 0
               if h==1
                  buff1=sprintf('%.0f',i);
               else
                  buff1=sprintf(', %.0f',i);
               end;
               buff = [buff buff1];
               h=2;
            end;
        end;
        MyPrint(Output,buff);
    end;
    if isempty(data.items_sd)==0
        buff = 'Items selected as SD items                  : ';
        [f1,f2]=size(data.items_sd);
        h=1;
        buff_1='';
        for i=1:f2
            if h==1
                buff_2=sprintf('%.0f',data.items_sd(i));
                h=2;
            else
                buff_2=sprintf(', %.0f',data.items_sd(i));
           end;
           buff_1=[buff_1 buff_2];
        end;
        MyPrint(Output,[buff buff_1]);
    end;
    if isempty(data.iub)==0
        buff = 'Items selected as unbalanced                : ';
        [f1,f2]=size(data.iub);
        h=1;
        buff_1='';
        for i=1:f2
            if h==1
                buff_2=sprintf('%.0f',data.iub(i));
                h=2;
            else
                buff_2=sprintf(', %.0f',data.iub(i));
           end;
           buff_1=[buff_1 buff_2];
        end;
        MyPrint(Output,[buff buff_1]);
    end;
    
    if data.matrix_user_on==1
        buff = sprintf('Dispersion Matrix                           : User Defined'); MyPrint(Output, buff);
    else
        if data.Matrix==1
            buff = sprintf('Dispersion Matrix                           : Covariance Matrix'); MyPrint(Output, buff);
        elseif data.Matrix==2
            buff = sprintf('Dispersion Matrix                           : Pearson Correlations'); MyPrint(Output, buff);
        elseif data.Matrix==3
            buff = sprintf('Dispersion Matrix                           : Polychoric Correlations'); MyPrint(Output, buff);
        end;
    end;
    
    if data.forced_descriptives==1
        
        buff = 'Method for factor extraction                : Unweighted Least Squares (ULS)';
        MyPrint(Output, buff );
        switch data.Rotation
            case 1 %Orthogonal
                buff = 'Rotation Method                             : Varimax';
            case 2 %Oblicque
                buff = 'Rotation Method                             : Promin (Lorenzo-Seva, 1999)';
            case 3
                buff = 'Rotation Method                             : Semi-specified oblique Procrustes rotation (Browne, 1972b)';
            case 4
                buff = 'Rotation Method                             : Semi-specified orthogonal Procrustes rotation (Browne, 1972a)';
        end;
        MyPrint(Output, buff);
    end;
    
    buff1=clock;
    c=fix(buff1);
    month={};
    month{1}='January';month{2}='February';month{3}='March';month{4}='April';month{5}='May';month{6}='June';
    month{7}='July';month{8}='August';month{9}='September';month{10}='October';month{11}='November';month{12}='December';
    actual_month=month{c(2)};
    data.actual_date=[c(4),c(5),c(3),actual_month,c(1)];
    %corrected minutes
    if c(5)<10
        buff = sprintf('Analysis date                               : %.0f:0%.0f, %.0f-%s-%.0f',c(4),c(5),c(3),actual_month,c(1));
    else
        buff = sprintf('Analysis date                               : %.0f:%.0f, %.0f-%s-%.0f',c(4),c(5),c(3),actual_month,c(1));
    end;
    MyPrint(Output, buff);
    
    MyPrint(Output,' ');
    
    
    %%%%%%%%%%%%%% RTF %%%%%%%%%%%%%%
    
    %%CabezaDocumento

    MyPrint(Output3,'{\rtf1\ansi\ansicpg1252\uc1 \deff0\deflang3082\deflangfe3082 ');

    %%Tipos de letras disponibles
    MyPrint(Output3,'{\fonttbl{\f0\froman\fcharset0\fprq2{\*\panose 02020603050405020304}Times New Roman;}{\f1\fswiss\fcharset0\fprq2{\*\panose 020b0604020202020204}Arial;}{\f6\fmodern\fcharset0\fprq1{\*\panose 00000000000000000000}Courier;}} ');

    %%Colores disponibles
    MyPrint(Output3,'{\colortbl;\red0\green0\bue0;\red0\green0\blue255;\red0\green255\blue255;\red0\green255\blue0;\red255\green0\blue255;\red255\green0\blue0;\red255\green255\blue0;\red255\green255\blue255;\red0\green0\blue128;\red0\green128\blue128;\red0\green128\blue0;\red128\green0\blue128;\red128\green0\blue0;\red128\green128\blue0;\red128\green128\blue128;\red192\green192\blue192;\red179\green179\blue179;} ');

    %%Estilo de hoja
    MyPrint(Output3,'{\stylesheet{\ql \li0\ri0\widctlpar\aspalpha\aspnum\faauto\adjustright\rin0\lin0\itap0 \fs24\lang3082\langfe3082\cgrid\langnp3082\langfenp3082 \snext0 Normal;}{\*\cs10 \additive Default Paragraph Font;}{\s15\ql \li0\ri0\widctlpar \tqc\tx4153\tqr\tx8306\aspalpha\aspnum\faauto\adjustright\rin0\lin0\itap0 \fs24\lang3082\langfe3082\cgrid\langnp3082\langfenp3082 \sbasedon0 \snext15 footer;}{\*\cs16 \additive \sbasedon10 page number;}} ');

    %%Informacion para Propiedades del documento
    titulo='Output';
    autor='Psychological Test Toolbox';
    operador='-';
    companyia='Universitat Rovira i Virgili';
    buff = ['{\info{\title ' titulo '}{\author ' autor '}{\operator ' operador '}{\creatim\yr0\mo0\dy0\hr0}{\revtim\yr0\mo0\dy0\hr0\min0}{\version1}{\edmins2}{\nofpages0}{\nofwords0}{\nofchars0}{\*\company ' companyia '}{\nofcharsws0}{\vern8249}}'];
    MyPrint(Output3, buff);

    %%retorno de carro en blanco
    MyPrint(Output3,'\par ');
    
    %%Imprimir el texto centrado
    MyPrint(Output3,'\qc \ul Details of Analysis \ul0');
    MyPrint(Output3,'\par ');
    MyPrint(Output3,'\ql');
    MyPrint(Output3,'\par ');
    interline='\trowd\trgaph144\clbrdrt\brdrs\clbrdrl\brdrs\clbrdrb\brdrs\clbrdrr\brdrs\cellx5000\clbrdrt\brdrs\clbrdrl\brdrs\clbrdrb\brdrs\clbrdrr\brdrs\cellx10000';
    MyPrint(Output3,interline);
%     buff = sprintf('\\intbl Matrix analized: \\cell %s \\cell \\row',data.name); MyPrint(Output3, buff);
    %data path contains "\" symbol, which cause conflict with rtf
    %programing language.
    [h1,h2]=size(data.path);
    buff_path=[];
    for i=1:h2
        if strcmp(data.path(i),'\')
            buff_path=[buff_path '\\'];
        else
            buff_path=[buff_path data.path(i)];
        end;
    end;
    buff = sprintf('\\intbl File path: \\cell %s \\cell \\row',buff_path); MyPrint(Output3, buff);
    if data.matrix_user_on==0
        MyPrint(Output3,interline);
        buff = sprintf('\\intbl Number of participants:\\cell %5.0f \\cell \\row',data.N_original); MyPrint(Output3, buff);
    end;
    if data.missings_on==1
        MyPrint(Output3,interline);
        buff = sprintf('\\intbl Number of participants without missing data:\\cell %5.0f \\cell \\row',data.N_sensemiss); MyPrint(Output3, buff);
    end;
    MyPrint(Output3,interline);
    buff = sprintf('\\intbl Number of items: \\cell %5.0f \\cell \\row',data.n); MyPrint(Output3, buff);

    cellrow=' \cell \row';
    
    [tmp, m_t]=size(A);
    [m,tmp]=size(char(data.inclosos));
    if tmp > m
        m=tmp;
    end;
    if m_t == m
        MyPrint(Output3,interline);
        MyPrint(Output3,'\intbl Items included in the analysis: \cell ALL \cell \row');
                      
    else
        buff = '\intbl Items included in the analysis: \cell ';
        for i=1:m-1
            buff1=sprintf('%.0f, ',data.inclosos(i));
            buff = [buff buff1];
        end;
        buff1=sprintf('%.0f',data.inclosos(m));
        buff = [buff buff1];
        buff=[buff cellrow];
        MyPrint(Output3,interline);
        MyPrint(Output3,buff);
        
        buff = '\intbl Items excluded in the analysis: \cell ';
        h=1;
        for i=1:m_t
            in=0;
            for j=1:m
                if data.inclosos(j) == i
                    in=1;
                    break;
                end;
            end;
            if in == 0
               if h==1
                  buff1=sprintf('%.0f',i);
               else
                  buff1=sprintf(', %.0f',i);
               end;
               buff = [buff buff1];
               h=2;
            end;
        end;
        MyPrint(Output3,interline);
        buff=[buff cellrow];
        MyPrint(Output3,buff);
    end;
    
    if isempty(data.items_sd)==0
        buff = '\intbl Items selected as SD items: \cell ';
        [f1,f2]=size(data.items_sd);
        h=1;
        for i=1:f2
            if h==1
                buff1=sprintf('%.0f',data.items_sd(i));
                buff=[buff buff1];
                h=2;
            else
                buff1=sprintf(', %.0f',data.items_sd(i));
                buff=[buff buff1];
            end;
        end;
        buff=[buff cellrow];
        MyPrint(Output3,interline);
        MyPrint(Output3,buff);
    end;
    if isempty(data.iub)==0
        buff = '\intbl Items selected as unbalanced: \cell ';
        [f1,f2]=size(data.iub);
        h=1;
        for i=1:f2
            if h==1
                buff1=sprintf('%.0f',data.iub(i));
                buff=[buff buff1];
                h=2;
            else
                buff1=sprintf(', %.0f',data.iub(i));
                buff=[buff buff1];
           end;
        end;
        buff=[buff cellrow];
        MyPrint(Output3,interline);
        MyPrint(Output3,buff);
    end;
    
    if data.matrix_user_on==1
        buff = sprintf('\\intbl Dispersion Matrix: \\cell User Defined \\cell \\row'); 
    else
        if data.Matrix==1
            buff = sprintf('\\intbl Dispersion Matrix: \\cell Covariance Matrix \\cell \\row');
        elseif data.Matrix==2
            buff = sprintf('\\intbl Dispersion Matrix: \\cell Pearson Correlations \\cell \\row');
        elseif data.Matrix==3
            buff = sprintf('\\intbl Dispersion Matrix: \\cell Polychoric Correlations \\cell \\row');
        end;
    end;
    MyPrint(Output3,interline);
    MyPrint(Output3, buff);
    
    if data.forced_descriptives==1
        
        buff = '\intbl Method for factor extraction: \cell Unweighted Least Squares (ULS) \cell \row';
        MyPrint(Output3,interline);
        MyPrint(Output3, buff );
        switch data.Rotation
            case 1 %Orthogonal
                buff = '\intbl Rotation Method: \cell Varimax \cell \row';
            case 2 %Oblicque
                buff = '\intbl Rotation Method: \cell Promin (Lorenzo-Seva, 1999) \cell \row';
            case 3
                buff = '\intbl Rotation Method: \cell Semi-specified oblique Procrustes rotation (Browne, 1972b) \cell \row';
            case 4
                buff = '\intbl Rotation Method: \cell Semi-specified orthogonal Procrustes rotation (Browne, 1972a) \cell \row';
        end;
        MyPrint(Output3,interline);
        MyPrint(Output3, buff);
    end;
    
    buff1=clock;
    c=fix(buff1);
    month={};
    month{1}='January';month{2}='February';month{3}='March';month{4}='April';month{5}='May';month{6}='June';
    month{7}='July';month{8}='August';month{9}='September';month{10}='October';month{11}='November';month{12}='December';
    actual_month=month{c(2)};
    %corrected minutes
    if c(5)<10
        buff = sprintf('\\intbl Analysis date : \\cell %.0f:0%.0f, %.0f-%s-%.0f  \\cell \\row \\pard \\par',c(4),c(5),c(3),actual_month,c(1));
    else
        buff = sprintf('\\intbl Analysis date : \\cell %.0f:%.0f, %.0f-%s-%.0f  \\cell \\row \\pard \\par',c(4),c(5),c(3),actual_month,c(1));
    end;
    MyPrint(Output3,interline);
    MyPrint(Output3, buff);
    
    buff=sprintf('%.0f-%s-%.0f, %.0f:%.0f',c(3),actual_month,c(1),c(4),c(5));
    data.actual_date=buff;
    
    setappdata(0,'data',data);  

    

return;

function Print_Factor_Analysis(Output,Output2,Output3)

    data=getappdata(0,'data');

    [f1,f2]=size(data.items_contingut);
    
    buff={};
    for i=1:f2
            buff{i}=sprintf('%s',data.labels{data.items_contingut(i)});
    end;
    labels_contingut=buff; %ETIQUETES DE CONTINGUT
    
    if ischar(labels_contingut)
        str=cellstr(labels_contingut);
    else
        str=labels_contingut;
    end;


    [ml,tmp]=size(str);
     ml = max([ml;tmp]);

    s=0;
    for i=1:ml
        if s < length(str{i})
            s= length(str{i});
        end;
    end;
    if s>30, s=30;end;
    if s<5 , s=5;end;
    
    [f1,f2]=size(data.itemsa);
    buff={};
    for i=1:f2
        buff{i}=sprintf('%s',data.labels{data.itemsa(i)});
    end;
    labels_tots=buff;
    labels_tots_enordre=data.labelsa;
    
    checking_DS=data.checking_DS;
    checking_AQ=data.checking_AQ;
    P=data.P;
    items=data.itemsa';
    [f1,f2]=size(data.P);
    r_c=f2-checking_DS-checking_AQ;
    Pc=data.Pc;

    %%%%%%%%%%%%%% LATEX %%%%%%%%%%%%%% 
    
    if checking_DS==0 && checking_AQ==0
        buff='\section{Exploratory Factor Analysis without controlling bias}';
    elseif checking_DS==1 && checking_AQ==0
        buff='\section{Exploratory Factor Analysis controlling Social Desirability}';
    elseif checking_DS==0 && checking_AQ==1
        buff='\section{Exploratory Factor Analysis controlling Acquiescence}';
    elseif checking_DS==1 && checking_AQ==1
        buff='\section{Exploratory Factor Analysis controlling Social Desirability and Acquiescence}';
    end;
    
    if isfield(data,'GFI')
    
    MyPrint(Output2,buff); MyPrint(Output2,'~ \');MyPrint(Output2,' ');
    buff=('Goodness of Fit Index (GFI) =');
    buff1=sprintf('% 7.4f ',data.GFI);
    buff4='\\';
    MyPrint(Output2,[buff buff1 buff4]);
    
    clearvars buff buff2 buff3 buff4
    
    end
    
    buff4='\\';
    [f1,f2] = size(P);
    MyPrint(Output2,'\begin{center}');
    buff='\begin{longtable}[H]';
    buff1=sprintf('{l*{%-5.0f}{S}}',f2+checking_DS+checking_AQ);
    MyPrint(Output2,[buff buff1]);
    
    MyPrint(Output2,'\caption{Rotated Loading Matrix}\\');
    MyPrint(Output2,'\toprule');
    
    buff_it='\multicolumn{1}{l}{\textbf';
    buff_other='\multicolumn{1}{c}{\textbf';
    if checking_DS==1 && checking_AQ==0
        buff=[buff_it '{Item}} & ' buff_other '{SD}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' & %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
        
    elseif checking_DS==0 && checking_AQ==1
        buff=[buff_it '{Item}} & ' buff_other '{AC}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' & %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
        
    elseif checking_DS==1 && checking_AQ==1
        buff=[buff_it '{Item}} & ' buff_other '{SD}} &' buff_other '{AC}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' &  %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
        
    elseif checking_DS==0 && checking_AQ==0
        buff=[buff_it '{Item}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' & %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
    end;
    MyPrint(Output2,buff4);
    MyPrint(Output2,'\midrule');
    MyPrint(Output2,'\endfirsthead');
    buff='\multicolumn';
    buff1 = sprintf('{%2.0f}{c}',checking_DS+checking_AQ+f2);
    MyPrint(Output2,[buff buff1]);
    MyPrint(Output2,'{\tablename\ \thetable\ -- \textit{(Continued from previous page)}} \\');
    MyPrint(Output2,'\toprule');
    if checking_DS==1 && checking_AQ==0
        buff=[buff_it '{Item}} & ' buff_other '{SD}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' & %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
        
    elseif checking_DS==0 && checking_AQ==1
        buff=[buff_it '{Item}} & ' buff_other '{AC}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' & %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
        
    elseif checking_DS==1 && checking_AQ==1
        buff=[buff_it '{Item}} & ' buff_other '{SD}} &' buff_other '{AC}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' &  %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
        
    elseif checking_DS==0 && checking_AQ==0
        buff=[buff_it '{Item}} '];
        MyPrint(Output2,buff);
        for i=1:r_c
            buff2=sprintf(' & %s{Factor %.0f}}',buff_other,i);
            MyPrint(Output2,buff2);
        end;
    end;
    MyPrint(Output2,buff4);
    MyPrint(Output2,'\midrule');
    MyPrint(Output2,'\endhead');
    buff='\bottomrule \multicolumn';
    buff1 = sprintf('{%2.0f}',checking_DS+checking_AQ+f2);
    buff2 = '{r}{\textit{Continued on next page}} ';
    MyPrint(Output2,[buff buff1 buff2 buff4]);
    MyPrint(Output2,'\endfoot');
    MyPrint(Output2,'\bottomrule');
    MyPrint(Output2,'\endlastfoot');
    
    [f1,f2]=size(items);
    
    for i=1:f1
        form=sprintf('%%-%d.%ds  ',s,s); 
        if checking_DS==1
            buff=sprintf(form,labels_tots{i});
        else
            buff=sprintf(form,str{i});
        end;
        buff2=sprintf(' & % 5.4f    ',P(i,:));
        MyPrint(Output2,[buff buff2 buff4]);
    end;
    MyPrint(Output2,'\end{longtable}'); 
    MyPrint(Output2,'\end{center}');
    MyPrint(Output2,' ');
    
    if r_c>1
        if checking_DS==0 && checking_AQ==0
            [f1,f2] = size(data.PHI);
            PHIprint=data.PHI;
        else
            switch data.Rotation
                case 1
                    [f1,f2] = size(data.PHIt);
                    PHIprint=data.PHIt;
                case 2
                    [f1,f2] = size(data.PHIt);
                    PHIprint=data.PHIt;
                case 3
                    [f1,f2] = size(data.PHIr);
                    PHIprint=data.PHIr;
                case 4
                    [f1,f2] = size(data.PHIr);
                    PHIprint=data.PHIr;
            end;
        end;
        if r_c==2
            buff=('Correlation between the 2 Factors = \textbf');
            buff1=sprintf('{% 5.4f} ',PHIprint(1,2));
            MyPrint(Output2,[buff buff1 buff4]);
            MyPrint(Output2,' ');
        else
            if data.Rotation == 2 || data.Rotation == 3
                MyPrint(Output2,'\begin{table}[!htb]');
                MyPrint(Output2,'\caption{Inter-factor Correlations}');
                MyPrint(Output2,'\label{taula:interfactor_correlations}');
                MyPrint(Output2,'\centering');

                buff='\begin{tabular}';
                buff1=sprintf('{l*{%-2.0f}{c}}',f2);
                MyPrint(Output2,[buff buff1 buff4]);
                for i=1:f1
                    buff=sprintf('% 5.4f   &',PHIprint(i,1:i));
                    [f1,f2]=size(buff);
                    buff2=buff(1:(f2-1));
                    MyPrint(Output2,[buff2 buff4]);
                end;
                MyPrint(Output2,'\\');
                MyPrint(Output2,'\end{tabular}');
                MyPrint(Output2,'\end{table}');
            end;
       end;
    end;
    buff=sprintf('Bentler''s simplicity = % 5.4f',bentler(Pc));
    MyPrint(Output2,[buff buff4]);    
    MyPrint(Output2,' ');
    buff=sprintf('Lorenzo-Seva''s simplicity = % 5.4f',zsi(Pc));
    MyPrint(Output2,[buff buff4]);
    MyPrint(Output2,' ');
    

    %%%%%%%%%%%%%% TEXT %%%%%%%%%%%%%%
    
    clearvars buff buff2 buff3 buff4;
    
     
    if checking_DS==0 && checking_AQ==0
        buff='Exploratory Factor Analysis without controlling bias';
    elseif checking_DS==1 && checking_AQ==0
        buff='Exploratory Factor Analysis controlling Social Desirability';
    elseif checking_DS==0 && checking_AQ==1
        buff='Exploratory Factor Analysis controlling Acquiescence';
    elseif checking_DS==1 && checking_AQ==1
        buff='Exploratory Factor Analysis controlling Social Desirability and Acquiescence';
    end;
    
    
    MyPrint(Output,'-----------------------------------------------------------------------');
    MyPrint(Output,buff);
    if isfield(data,'GFI')
        MyPrint(Output,'-----------------------------------------------------------------------');
        MyPrint(Output,' ');
        MyPrint(Output,'GOODNESS OF FIT STATISTICS');
        MyPrint(Output,' ');
        buff = sprintf('Goodness of Fit Index (GFI) = %7.4f',data.GFI);
        MyPrint(Output,buff);
        MyPrint(Output,' ');
        MyPrint(Output,'-----------------------------------------------------------------------');
    end
    
    clearvars buff buff2 buff3 buff4;
    
    MyPrint(Output,' ');
    MyPrint(Output,'Rotated loading matrix');
    MyPrint(Output,' ');
    if checking_DS==1 && checking_AQ==0
        form=sprintf('%%-%d.%ds   SD      ',s,s);
        buff=sprintf(form,'Item');
        
        for i=1:r_c
            if isfield(data,'factor_labels')==0
                buff2{i}=sprintf('   Factor %.0f',i);
            else
                [g1,g2]=size(data.factor_labels{i});
                switch g2
                    case 1
                        buff2{i}=sprintf('   %1s       ',data.factor_labels{i});
                    case 2 
                        buff2{i}=sprintf('   %2s      ',data.factor_labels{i});
                    case 3
                        buff2{i}=sprintf('   %3s     ',data.factor_labels{i});
                    case 4
                        buff2{i}=sprintf('   %4s    ',data.factor_labels{i});
                    case 5
                        buff2{i}=sprintf('   %5s   ',data.factor_labels{i});
                end;
            end;
%             buff2{i}=sprintf('   Factor %.0f',i);
        end;
        buff3=sprintf('%s',buff2{:});
    end;
    if checking_DS==0 && checking_AQ==1;
        form=sprintf('%%-%d.%ds   AC      ',s,s);
        buff=sprintf(form,'Item');
        
        for i=1:r_c
            if isfield(data,'factor_labels')==0
                buff2{i}=sprintf('   Factor %.0f',i);
            else
                [g1,g2]=size(data.factor_labels{i});
                switch g2
                    case 1
                        buff2{i}=sprintf('   %1s       ',data.factor_labels{i});
                    case 2 
                        buff2{i}=sprintf('   %2s      ',data.factor_labels{i});
                    case 3
                        buff2{i}=sprintf('   %3s     ',data.factor_labels{i});
                    case 4
                        buff2{i}=sprintf('   %4s    ',data.factor_labels{i});
                    case 5
                        buff2{i}=sprintf('   %5s   ',data.factor_labels{i});
                end;
            end;
%             buff2{i}=sprintf('   Factor %.0f',i);
        end;
        buff3=sprintf('%s',buff2{:});
    end;
    if checking_DS==1 && checking_AQ==1
        form=sprintf('%%-%d.%ds   SD         AC      ',s,s);
        buff=sprintf(form,'Item');
        
        for i=1:r_c
            if isfield(data,'factor_labels')==0
                buff2{i}=sprintf('   Factor %.0f',i);
            else
                [g1,g2]=size(data.factor_labels{i});
                switch g2
                    case 1
                        buff2{i}=sprintf('   %1s       ',data.factor_labels{i});
                    case 2 
                        buff2{i}=sprintf('   %2s      ',data.factor_labels{i});
                    case 3
                        buff2{i}=sprintf('   %3s     ',data.factor_labels{i});
                    case 4
                        buff2{i}=sprintf('   %4s    ',data.factor_labels{i});
                    case 5
                        buff2{i}=sprintf('   %5s   ',data.factor_labels{i});
                end;
            end;
%             buff2{i}=sprintf('   Factor %.0f',i);
        end;
        buff3=sprintf('%s',buff2{:});
    end;
    if checking_DS==0 && checking_AQ==0
        form=sprintf('%%-%d.%ds',s,s);
        buff=sprintf(form,'Item');
        
        for i=1:r_c
            if isfield(data,'factor_labels')==0
                buff2{i}=sprintf('   Factor %.0f',i);
            else
                [g1,g2]=size(data.factor_labels{i});
                switch g2
                    case 1
                        buff2{i}=sprintf('   %1s       ',data.factor_labels{i});
                    case 2 
                        buff2{i}=sprintf('   %2s      ',data.factor_labels{i});
                    case 3
                        buff2{i}=sprintf('   %3s     ',data.factor_labels{i});
                    case 4
                        buff2{i}=sprintf('   %4s    ',data.factor_labels{i});
                    case 5
                        buff2{i}=sprintf('   %5s   ',data.factor_labels{i});
                end;
            end;
%             buff2{i}=sprintf('   Factor %.0f',i);
        end;
        buff3=sprintf('%s',buff2{:});
    end;
    MyPrint(Output,[buff buff3]);

    [f1,f2]=size(items);
        
    for i=1:f1
        form=sprintf('%%-%d.%ds  ',s,s);   
        if checking_DS==1
            buff=sprintf(form,labels_tots{i});
        else
            buff=sprintf(form,str{i});
        end;
        buff2=sprintf('% 5.4f    ',P(i,:));
        MyPrint(Output,[buff buff2]);
    end;
    
    if r_c>1
       if data.Rotation == 2 || data.Rotation == 3
            MyPrint(Output,' ');    
            MyPrint(Output,'Inter-factor correlations');
            if checking_DS==0 && checking_AQ==0
                [f1,f2] = size(PHI);
                PHIprint=PHI;
            else
                switch data.Rotation
                    case 1
                        [f1,f2] = size(data.PHIt);
                        PHIprint=data.PHIt;
                    case 2
                        [f1,f2] = size(data.PHIt);
                        PHIprint=data.PHIt;
                    case 3
                        [f1,f2] = size(data.PHIr);
                        PHIprint=data.PHIr;
                    case 4
                        [f1,f2] = size(data.PHIr);
                        PHIprint=data.PHIr;
                end;           
            end;
            if r_c==2
                buff=sprintf('Correlation between the 2 Factors: % 5.4f ',PHIprint(1,2));
                MyPrint(Output,buff);
            else
                buff='      ';
                for i=1:f1
                    if isfield(data,'factor_labels')==0
                        buff1=sprintf('F%2.0f       ',i);
                    else
                        [g1,g2]=size(data.factor_labels{i});
                        switch g2
                            case 1
                                buff1=sprintf('%1s         ',data.factor_labels{i});
                            case 2 
                                buff1=sprintf('%2s        ',data.factor_labels{i});
                            case 3
                                buff1=sprintf('%3s       ',data.factor_labels{i});
                            case 4
                                buff1=sprintf('%4s      ',data.factor_labels{i});
                            case 5
                                buff1=sprintf('%5s     ',data.factor_labels{i});
                        end;
                    end;
%                     buff1=sprintf('F%2.0f       ',i);
                    buff=[buff buff1];
                end;
                MyPrint(Output,buff);
                for i=1:f1
                    if isfield(data,'factor_labels')==0
                        buff=sprintf('F%2.0f  ',i);
                    else
                        [g1,g2]=size(data.factor_labels{i});
                        switch g2
                            case 1
                                buff=sprintf('%1s    ',data.factor_labels{i});
                            case 2 
                                buff=sprintf('%2s   ',data.factor_labels{i});
                            case 3
                                buff=sprintf('%3s  ',data.factor_labels{i});
                            case 4
                                buff=sprintf('%4s ',data.factor_labels{i});
                            case 5
                                buff=sprintf('%5s',data.factor_labels{i});
                        end;
                    end;
%                     buff=sprintf('F%2.0f  ',i);
                    buff1=sprintf('% 5.4f   ',PHIprint(i,1:i));
                    MyPrint(Output,[buff buff1]);
                end;    
            end;
        end;
    
        MyPrint(Output,' ')
        MyPrint(Output,'-----------------------------------------------------------------------');
        MyPrint(Output,' ')
        MyPrint(Output,'Indices of factor simplicity');
        MyPrint(Output,'Bentler (1977) & Lorenzo-Seva (2003)');
        MyPrint(Output,' ')
        MyPrint(Output,'Bentler''s simplicity');
        buff=sprintf('% 5.4f',bentler(Pc));
        MyPrint(Output,buff);    
        MyPrint(Output,' ');
        MyPrint(Output,'Lorenzo-Seva''s simplicity');
        buff=sprintf('% 5.4f',zsi(Pc));
        MyPrint(Output,buff);
        MyPrint(Output,' ');
    end;
    
    
    %%%%%%%%%%%%%% RTF %%%%%%%%%%%%%%
    
    
    int='\intbl ';
    cell1='\cell';
    row='\row';
    pard='\pard \par';
    
    clearvars buff buff2 buff3
    
    if checking_DS==0 && checking_AQ==0
        buff='\qc \ul Exploratory Factor Analysis without controlling bias\ul0';
    elseif checking_DS==1 && checking_AQ==0
        buff='\qc \ul Exploratory Factor Analysis controlling Social Desirability\ul0';
    elseif checking_DS==0 && checking_AQ==1
        buff='\qc \ul Exploratory Factor Analysis controlling Acquiescence\ul0';
    elseif checking_DS==1 && checking_AQ==1
        buff='\qc \ul Exploratory Factor Analysis controlling Social Desirability and Acquiescence\ul0';
    end;
    MyPrint(Output3,'\par');
    MyPrint(Output3,buff);
    MyPrint(Output3,'\par');
    
    if isfield(data,'GFI')
        MyPrint(Output3,'\par');MyPrint(Output3,'\par');
        buff = sprintf('Goodness of Fit Index (GFI) = %7.4f',data.GFI);
        MyPrint(Output3,['\ql ' buff]);
        MyPrint(Output3,'\par');MyPrint(Output3,'\par');
    end
    
    a=checking_DS+checking_AQ+r_c+1;
    buff=cell(a,1);
    buff{1}='Item';
    
    if checking_DS==1 && checking_AQ==0
        buff{2}='SD';
    elseif checking_DS==0 && checking_AQ==1;
        buff{2}='AC';
    elseif checking_DS==1 && checking_AQ==1
        buff{2}='SD';
        buff{3}='AC';
    elseif checking_DS==0 && checking_AQ==0
    end;
    
    for i=1:r_c
        buff{i+checking_DS+checking_AQ+1}=sprintf('Factor %.0f',i);
    end;
    
    MyPrint(Output3,'\par');
    MyPrint(Output3,'\qc \ul Rotated Loading Matrix \ul0');
    MyPrint(Output3,'\par');
    MyPrint(Output3,'\par');
    if checking_DS==1
        labels_ok=labels_tots;
    else
        labels_ok=str;
    end;
    Print_RTF_P(P,Output3,buff,labels_ok);
    
    
    if r_c>1
       if data.Rotation == 2 || data.Rotation == 3
            
            if checking_DS==0 && checking_AQ==0
                [f1,f2] = size(PHI);
                PHIprint=PHI;
            else
                switch data.Rotation
                    case 1
                        [f1,f2] = size(data.PHIt);
                        PHIprint=data.PHIt;
                    case 2
                        [f1,f2] = size(data.PHIt);
                        PHIprint=data.PHIt;
                    case 3
                        [f1,f2] = size(data.PHIr);
                        PHIprint=data.PHIr;
                    case 4
                        [f1,f2] = size(data.PHIr);
                        PHIprint=data.PHIr;
                end;           
            end;
            if r_c==2
                MyPrint(Output3,'\par');
                buff=sprintf('Correlation between the 2 Factors: % 5.4f ',PHIprint(1,2));
                MyPrint(Output3,buff);
                MyPrint(Output3,'\par');
            else
                numtables=ceil(f2/10); %nombre de taules necessaries per imprimir correctament la matriu de correlacions
                %Ho fem per facilitar la lectura de la taula, per quan tenim moltes variables. (maxim d'amplada de 10 per taula)
                
                a=(1:f2);
                str=num2cell(a);

                for l=1:numtables
                    [f1,f2] = size(PHIprint);

                    leng=l*10;
                    cof=10*(l-1);

                    if cof<f2 && cof+10<f2
                        PHI2=PHIprint(:,1+cof:10+cof);
                        str2=str(1+cof:10+cof);
                    else
                        PHI2=PHIprint(:,1+cof:f2);
                        str2=str(1+cof:f2);
                    end;

                    a=f2/(leng);
                    if a>1
                        numb=10;
                    elseif a<1
                        numb=f2-(10*(l-1));
                    end;
                
                    MyPrint(Output3,'\par');MyPrint(Output3,'\par');
                    buff_rtf='\qc \ul Inter-factor correlations\ul0';
                    buff2=sprintf(' (Part %.0f of %.0f )',l,numtables);
                    if numtables==1
                        MyPrint(Output3,buff_rtf);
                    else
                        MyPrint(Output3,[buff_rtf buff2]);
                    end;
                    MyPrint(Output3,'\par');
                    MyPrint(Output3,'\par');
                    MyPrint(Output3,'\ql');
                    interline_cap=[];
                    for i=1:numb+1
                        if i==1
                            buff='\trowd\trgaph72\clbrdrt\brdrs\clbrdrl\brdrs\clbrdrb\brdrs\clbrdrr\brdrs\';
                        else
                            buff='\clbrdrt\brdrs\clbrdrl\brdrs\clbrdrb\brdrs\clbrdrr\brdrs\';
                        end;
                        buff2=sprintf('cellx%.0f',910*i);
                        buff3=[buff buff2];
                        interline_cap=[interline_cap buff3];
                    end;
                    
                    buff_rtf='\cell';
                    dif=f2-cof;
                    if dif>10
                        for i=1:10
                            buff_rtf1=sprintf(' F %-5.0f',str2{i});
                            buff_rtf=[buff_rtf buff_rtf1 cell1];
                        end;
                    else
                        for i=1:f2-cof
                            buff_rtf1=sprintf(' F %-3.0f',str2{i});
                            buff_rtf=[buff_rtf buff_rtf1 cell1];
                        end;
                    end;
                    MyPrint(Output3,interline_cap);
                    MyPrint(Output3,[int buff_rtf row]);

                    [f1,f2]=size(PHI2);
                    
                    for i=1:f1-cof
                        buff0=sprintf('F%3.0f ',str{i+cof}); 
                        if i<=10
                            buff_rtf=sprintf(' % 4.3f \\cell',PHI2(i+cof,1:i));
                        else
                            buff_rtf=sprintf(' % 4.3f \\cell',PHI2(i+cof,1:10));
                        end;

                        emptycells=[];
                        for j=1:f2-i
                            buff9=sprintf('%s',cell1);
                            emptycells=[emptycells buff9];
                        end;
                        numberofemptycells=f2-i;
                        numberoffullcells=f2-numberofemptycells;

                        interline_fila=[];
                        for k=1:numb+1
                            if k==1
                                buff='\trowd\trgaph72\clbrdrt\brdrs\clbrdrl\brdrs\clbrdrb\brdrs\clbrdrr\brdrs\'; %la primera, la del numbero de item
                            else
                                if k<=numberoffullcells+1
                                    buff='\clbrdrt\brdrs\clbrdrl\brdrs\clbrdrb\brdrs\clbrdrr\brdrs\'; %les cel·les amb nombres, que tinguin bordes
                                else
                                    buff='\';                                                       %les cel·les buides, sense bordes
                                end;
                            end;
                            buff2=sprintf('cellx%.0f',910*k);
                            buff3=[buff buff2];
                            interline_fila=[interline_fila buff3];
                        end;

                        MyPrint(Output3,interline_fila);
                        if i==f1-cof
                            MyPrint(Output3,[int buff0 cell1 buff_rtf emptycells row pard]);    
                        else
                            MyPrint(Output3,[int buff0 cell1 buff_rtf emptycells row]);
                        end;
                    end;
                end;
                                
            end;
        end;
        
        MyPrint(Output3,'\par');
        buff1='Bentler''s simplicity = ';
        buff2=sprintf('% 5.4f',bentler(Pc));
        MyPrint(Output3,[buff1 buff2]);  
        
        MyPrint(Output3,'\par');
        MyPrint(Output3,'\par');
        
        buff1='Lorenzo-Seva''s simplicity = ';
        buff2=sprintf('% 5.4f',zsi(Pc));
        MyPrint(Output3,[buff1 buff2]);
        MyPrint(Output3,'\par');
        MyPrint(Output3,'\par');
    end;
        
    MyPrint(Output3,'\par');
    
return;


function PrintFactorScores(data,Output,Output2,Output3)

    checking_DS=data.checking_DS;
    checking_AQ=data.checking_AQ;
    
    [f1,f2]=size(data.P);
    r=f2-checking_DS-checking_AQ;

    N=data.N_new;
    th = data.th;
    se = data.se;
    th_li=data.th_li;
    th_ls=data.th_ls;
    reli=data.reli;
    
    MyPrint(Output,'-----------------------------------------------------------------------');
    MyPrint(Output,' ');
    buff='RELIABILITY OF ';
    if data.Rotation==1 || data.Rotation==4
        buff2='ORTHOGONAL EAP SCORES';
    elseif data.Rotation==2 || data.Rotation==3
        buff2='PHI-INFORMATION OBLIQUE EAP SCORES';
    end;
    MyPrint(Output,[buff buff2]);
    MyPrint(Output,'Ferrando & Lorenzo-Seva (2016)');
    MyPrint(Output,' ');
    
    [f1,f2]=size(reli);
    prov=checking_DS+checking_AQ;
    MyPrint(Output,'Factor         EAP Reliability estimate');
    MyPrint(Output,' ');
    for i=1:r+checking_DS+checking_AQ
        if i==1 && checking_DS==1
            buff='SD           :';
        elseif i==1 && checking_DS==0 && checking_AQ==1
            buff='Acquiescence :';
        elseif i==2 && checking_DS==1 && checking_AQ==1
            buff='Acquiescence :';
        else
            if isfield(data,'factor_labels')==0
                buff=sprintf('Factor %.0f     :',i-prov);
            else
                [g1,g2]=size(data.factor_labels{i-prov});
                switch g2
                    case 1
                        buff=sprintf('%1s            :',data.factor_labels{i-prov});
                    case 2
                        buff=sprintf('%2s           :',data.factor_labels{i-prov});
                    case 3
                        buff=sprintf('%3s          :',data.factor_labels{i-prov});
                    case 4
                        buff=sprintf('%4s         :',data.factor_labels{i-prov});
                    case 5
                        buff=sprintf('%5s        :',data.factor_labels{i-prov});
                end;
            end;
        end;
        
        if data.Matrix==1 || data.Matrix==2
            buff2=sprintf(' %.4f',reli(i));
        else
            [h1,h2]=size(reli);
            if h2==1
                buff2=sprintf(' %.4f',reli(i));
            else
                buff2=sprintf(' %.4f',mean(reli(:,i)));
            end
        end;
        MyPrint(Output,[buff buff2]);
    end;
        

%Calcular les linies de puntuacions a imprir

    TotalLines = N + N*(r+checking_DS+checking_AQ);
    
    %Print th score
    MyPrint(Output,' ');
    buff='PARTICIPANTS''S SCORES ON FACTORS: ';
    if data.Rotation==2 || data.Rotation==3
        buff2='PHI-Information Oblique EAP scores';
    elseif data.Rotation==1 || data.Rotation==4
        buff2='Orthogonal EAP scores';
    end;
    MyPrint(Output,[buff buff2]);
    MyPrint(Output,'Rescaled to mean = 50 and standard deviation = 10 in the sample');
    MyPrint(Output,' ');
    MyPrint(Output,'Ferrando & Lorenzo-Seva (2016)');
    MyPrint(Output,' ');
    MyPrint(Output,' ');
   
    buff3 = 'Participant   ';
    if checking_DS==1 && checking_AQ==1
        buff2='DS         AQ         ';
    elseif checking_DS==1 && checking_AQ==0
        buff2='DS          ';
    elseif checking_DS==0 && checking_AQ==1
        buff2='AQ          ';
    else
        buff2='';
    end;
    buff='';
    
    for i=1:r
        if isfield(data,'factor_labels')==0
            buff1=sprintf('F%2.0f        ',i);
            buff =[buff buff1];
        else
            [g1,g2]=size(data.factor_labels{i});
                switch g2
                    case 1
                        buff1=sprintf('%1s          ',data.factor_labels{i});
                    case 2
                        buff1=sprintf('%2s         ',data.factor_labels{i});
                    case 3
                        buff1=sprintf('%3s        ',data.factor_labels{i});
                    case 4
                        buff1=sprintf('%4s       ',data.factor_labels{i});
                    case 5
                        buff1=sprintf('%5s      ',data.factor_labels{i});
                end;
            buff =[buff buff1];
        end;
    end;
    buff=[buff3 buff2 buff];

    MyPrint(Output,buff);
    
    BarCount = 0; bar1 = waitbar(BarCount,'Printing ... ','CreateCancelBtn','setappdata(gcbf,''canceling'',1)');
    
    setappdata(bar1,'canceling',0)
    TicPrint = tic;
    
    for i=1:N
        if getappdata(bar1,'canceling')
            break
        end;
        buff=sprintf('%4.0f         ',i);
        for j=1:r+(checking_DS+checking_AQ)
            buff1=sprintf('% 7.3f    ',th(i,j)*10+50);
            buff=[buff buff1];
        end;
        MyPrint(Output,buff);
        
        BarCount = BarCount + 1; 
        compT = toc(TicPrint);
        compT = compT*(TotalLines-BarCount)/BarCount;
        s_tmp{1}=['Printing ... (Remaining time = ' Time2String( compT ) ')'];
        waitbar(BarCount/TotalLines,bar1,s_tmp);
    end;
    
    if getappdata(bar1,'canceling')
        delete(bar1);
        return;
    end;

    MyPrint(Output,' ');
    MyPrint(Output,' ');
    for j=1:(r+checking_DS+checking_AQ)
        if j==1 && checking_DS==1
            buff='FACTOR: SOCIAL DESIRABILITY      ';
        elseif j==1 && checking_DS==0 && checking_AQ==1
            buff='FACTOR: ACQUIESCENCE      ';
        elseif j==2 && checking_DS==1 && checking_AQ==1
            buff='FACTOR: ACQUIESCENCE      ';
        else
            if isfield(data,'factor_labels')==0
                buff=sprintf('FACTOR: CONTENT %1.0f      ',j-prov);
            else
                buff=sprintf('FACTOR: %s      ',data.factor_labels{j-prov});
            end;
        end;
        MyPrint(Output,buff);
        MyPrint(Output,' ');

        switch data.Matrix
            case {1,2}
                  buff=sprintf('RELIABILITY OF EAP FACTOR SCORES:   % .3f          ',reli(j));
                  MyPrint(Output,buff);
                  MyPrint(Output,' ');
                  MyPrint(Output,'Participant   Estimate        Approximate 90%      Posterior');
            case 3   
                [h1,h2]=size(reli);
                if h2==1
                  buff=sprintf('RELIABILITY OF EAP FACTOR SCORES:   % .3f          ',reli(j));
                else
                  buff=sprintf('RELIABILITY OF EAP FACTOR SCORES:   % .3f          ',mean(reli(:,j)));
                end
                  MyPrint(Output,buff);
                  MyPrint(Output,' ');
                  if h2==1
                    MyPrint(Output,'Participant   Estimate        Approximate 90%      Posterior');
                  else
                    MyPrint(Output,'Participant   Estimate        Approximate 90%      Posterior   Reliability');
                  end
        end;
        MyPrint(Output,'              factor score    confidence interval  SD (PSD)');

        MyPrint(Output,' ');
        for i=1:N
            if getappdata(bar1,'canceling')
                break
            end;

            buff=sprintf('%4.0f         % 7.3f        ',i,th(i,j)*10+50);
            buff1=sprintf('(% 7.3f   % 7.3f)   ',th_li(i,j)*10+50,th_ls(i,j)*10+50);
            switch data.Matrix
                case {1,2}
                      buff2=sprintf('% .3f       ',se(j,j));
                case 3  
                    if h2==1
                      buff2=sprintf('% .3f       ',se(j,j));
                    else
                        buff2=sprintf('% .3f      % .3f',se(i,j),reli(i,j));
                    end
            end;

            buff =[ buff buff1 buff2];
            MyPrint(Output,buff);
            MyPrint(Output,' ');

            %Bar
            BarCount = BarCount + 1; 
            compT = toc(TicPrint);
            compT = compT*(TotalLines-BarCount)/BarCount;
            s_tmp=['Printing ... (Remaining time = ' Time2String( compT ) ')'];
            waitbar(BarCount/TotalLines,bar1,s_tmp);

        end;
    end;
    
    delete(bar1);
    
    MyPrint(Output,'-----------------------------------------------------------------------');

return;

function easter_egg (hObject, eventdata,handles)
    
    set(handles.panel_tab1,'backgroundcolor','w');
    
    set(handles.text01,'backgroundcolor','w');
    set(handles.text012,'backgroundcolor','w');
    set(handles.text021,'backgroundcolor','w');
    set(handles.text022,'backgroundcolor','w');
    set(handles.text03,'backgroundcolor','w');
    set(handles.text04,'backgroundcolor','w');
    set(handles.text05,'backgroundcolor','w');
    set(handles.text06,'backgroundcolor','w');

    je = javax.swing.JEditorPane('text/html', '<html><img src="file:/home/becari/Desktop/corrector/lib/cat.gif"/></html>');
    [hj,hc] =  javacomponent(je,[],handles.panel_tab1);
    set(hc, 'pos', [180,100,400,300]);
    
    handles.context_menu2=uicontextmenu;
    handles.item2=uimenu(handles.context_menu2,'Label','Another cat');
    
    handles.pbutton1=uicontrol(handles.panel_tab1,'Style','pushbutton',...
    'Units','pixels',...
    'position',[0 250 200 60],...
    'FontSize',16,...
    'fontname','Verdana',...
    'ForegroundColor',[.8 .2 .2],...
    'HorizontalAlignment','center',...
    'FontWeight','bold',...
    'BackgroundColor', 'w',...
    'String','Another cat!');

    t = timer;
    t.StartDelay = 6;
    t.TimerFcn = @(myTimerObj, thisEvent)delete(hc);
    start(t);

    set(handles.pbutton1,'Callback',{@easter_egg2, handles});

return;

function easter_egg2 (hObject, eventdata,handles)
    
    delete(handles.pbutton1);

    je = javax.swing.JEditorPane('text/html', '<html><img src="file:/home/becari/Desktop/corrector/lib/cat2.gif"/></html>');
    [hj,hc] =  javacomponent(je,[],handles.panel_tab1);
    set(hc, 'pos', [0,320,320,240]);
    
    
    handles.pbutton2=uicontrol(handles.panel_tab1,'Style','pushbutton',...
    'Units','pixels',...
    'position',[560 400 200 60],...
    'FontSize',18,...
    'fontname','Verdana',...
    'ForegroundColor',[.2 .6 .8],...
    'HorizontalAlignment','center',...
    'FontWeight','bold',...
    'BackgroundColor', 'w',...
    'String','Another one!');

    t = timer;
    t.StartDelay = 6;
    t.TimerFcn = @(myTimerObj, thisEvent)delete(hc);
    start(t);

    set(handles.pbutton2,'Callback',{@easter_egg3, handles});

return;

function easter_egg3 (hObject, eventdata,handles)
    
    delete(handles.pbutton2);
    
    je = javax.swing.JEditorPane('text/html', '<html><img src="file:/home/becari/Desktop/corrector/lib/cat3.gif"/></html>');
    [hj,hc] =  javacomponent(je,[],handles.panel_tab1);
    set(hc, 'pos', [452,0,308,232]);
    
    handles.pbutton3=uicontrol(handles.panel_tab1,'Style','pushbutton',...
    'Units','pixels',...
    'position',[250 425 250 100],...
    'FontSize',20,...
    'fontname','Verdana',...
    'ForegroundColor',[.2 .8 .2],...
    'HorizontalAlignment','center',...
    'FontWeight','bold',...
    'BackgroundColor', 'w',...
    'String','Just one more!');
    
    t = timer;
    t.StartDelay = 6;
    t.TimerFcn = @(myTimerObj, thisEvent)delete(hc);
    start(t);
    
    set(handles.pbutton3,'Callback',{@easter_egg4, handles});

return;

function easter_egg4 (hObject, eventdata,handles)
    
    delete(handles.pbutton3);

    je = javax.swing.JEditorPane('text/html', '<html><img src="file:/home/becari/Desktop/corrector/lib/serious_cat_is_serious.jpg"/></html>');
    [hj,hc] =  javacomponent(je,[],handles.panel_tab1);
    set(hc, 'pos', [161,64,437,471]);
   
    t = timer;
    t.StartDelay = 6;
    t.TimerFcn = @(myTimerObj, thisEvent)delete(hc);
    start(t);
    
    t2 = timer;
    t2.StartDelay = 6;
    t2.TimerFcn = @(myTimerObj, thisEvent)msgbox('Time to work! !');
    start(t2);
    
    set(handles.panel_tab1,'backgroundcolor',[.784 .949 .98]);
    
    set(handles.text01,'backgroundcolor',[.784 .949 .98]);
    set(handles.text012,'backgroundcolor',[.784 .949 .98]);
    set(handles.text021,'backgroundcolor',[.784 .949 .98]);
    set(handles.text022,'backgroundcolor',[.784 .949 .98]);
    set(handles.text03,'backgroundcolor',[.784 .949 .98]);
    set(handles.text04,'backgroundcolor',[.784 .949 .98]);
    set(handles.text05,'backgroundcolor',[.784 .949 .98]);
    set(handles.text06,'backgroundcolor',[.784 .949 .98]);
    
    set(handles.item1,...
    'Callback',{@no_easter_egg, handles});

return;

function no_easter_egg (hObject, eventdata,handles)

    msgbox('No more kittens! Time to work!');

return;

function Provide_Labels (hObject,eventdata,handles,gcf)

    try 
        figlab=Provide_factor_labels;
        waitfor(figlab);
    catch
 		disp(lasterr);
    end
    
    data=getappdata(0,'data');
    
return;

function jObj = waiting (handles,jObj,eventdata,hObject)

    % Call the icon by java
    iconsClassName = 'com.mathworks.widgets.BusyAffordance$AffordanceSize';
    iconsSizeEnums = javaMethod('values',iconsClassName);
    SIZE_32x32 = iconsSizeEnums(2);  % (1) = 16x16,  (2) = 32x32
    jObj = com.mathworks.widgets.BusyAffordance(SIZE_32x32, 'Computing ... Please wait');  % icon, label
    
    jObj.setPaintsWhenStopped(true);  % default = false
    jObj.useWhiteDots(false);         % default = false
    javacomponent(jObj.getComponent, [0,0,250,100], handles.fig_scoring);
    jObj.getComponent.setBackground(java.awt.Color(.941, .941, .941));  % orange
    jObj.start;
    
return;

function varargout = Cancel_Callback (gcf,event_data,handles,varargin)

    delete(gcbf);

return;

function varargout = Ok_Callback (gcbf,event_data,handles,varargin)

    data=getappdata(0,'data');
    
    value_miss=get(handles.missingvalue,'string');
    
    num3_1=isstrprop(value_miss,'digit');
    num3_2=isstrprop(value_miss,'punct'); %If it is a negative value
    find3_1=find(num3_1==0);
    empt3_1=isempty(find3_1);
    if empt3_1==0
        find3_2=find(num3_2==0);
        rev_empt3_2=isempty(find3_2);
    end;
    
    if isempty(value_miss) || (empt3_1==0 && rev_empt3_2~=0)
        errordlg('Please, insert a valid missing value','Psychological Test Toolbox: Error','Error');
        set(handles.missingvalue,'backgroundcolor',[.8 .2 .2]);
        return;
    end; 
    
    buff=find(data.X_new==str2num(value_miss));
    
    if isempty(buff)
        errordlg('The value selected is not present in the new subset','Psychological Test Toolbox: Error','Error');
        set(handles.missingvalue,'backgroundcolor',[.8 .2 .2]);
        return;
    end;
    
    % Missings value assigned
    data.missings_value_new = str2num(value_miss);
    data.missings_on_new=1;
    
    setappdata(0,'data',data);
    
    gcbf=handles.fig_miss;
    delete(gcbf);
    
return;


% function music (hObject, eventdata,handles)
% 
%     [y,Fs] = audioread('/home/becari/Desktop/corrector/Barcelona.wav');
%     
%     player = audioplayer(y,Fs);
%     
%     play(player);
% 
% return;