%% EAP_CONTINUOUS_OBLI: Compute the EAP for continuous data
%
% ARGUMENTS   : X    raw matrix.
%               P    Loading matrix.
%               PHI  Correlation matrix
%
% RETURN VALUE: th    factor scores.
%               th_li factor scores inferior limit.
%               th_ls factor scores upper limit.
%               se    standard errors
%               reli  reliability of factor scores
%
% UPDATE 18/04/2018: R will now be a input argument for enabling the use of
% the lineal model when using polychoric correlation matrix
%

function [th,th_li,th_ls,se,reli] = eap_continuous_obli(X,P,PHI,R)

   [n,m] = size(X);
   [m,r]=size(P);
   
   M = mean(X); Sx = std(X);
   DIF = X - (ones(n,1) * M);
   Z = DIF ./ (ones(n,1) * Sx);

%    R=corrcoef(X);

   th = (PHI*P'*R^(-1)*Z')';

   U = diag(diag(R - P*PHI*P'));

   VAR_E = (PHI^(-1) + P'*U^(-1)*P)^(-1);
   se = sqrt(diag(diag(VAR_E)));

   z90= 1.64485362695147;
  
% 90% approximate confidence interval
  th_li= zeros(n,r);
  th_ls= zeros(n,r);
  for i=1:n,
       tmp=[];
       for j=1:r,
           th_li(i,j) = th(i,j) - z90*se(j,j);
           th_ls(i,j) = th(i,j) + z90*se(j,j);
       end;
  end;

  reli=diag(eye - VAR_E);
   
return;
