%% EAPGRAD: EAP POINT ESTIMATES IN THE 2-FACTOR UVA MODEL WITH STANDARD ERRORS AND RELIABILITY ESTIMATES
%
% ARGUMENTS   : X     ->  VECTOR OF ITEM SCORES (SCORED 1 TO k)
%               LAM   ->  LOADING FACTOR PATTERN (items x dimension factors)
%               THRES ->  TRHRESHOLD MATRIX (dimension thresholds x items with a final row of zeros)
%               sigj  ->  VECTOR OF ITEM RESIDUAL STANDARD DEVIATIONS
%               nodos ->  MATRIX OF QUADRATURE POINTS AND WEIGHTS
%         index_nodos ->  INDEX MATRIX FOR nodos
%
% RETURN VALUE: TH    -> factor scores.
%               SE    -> standard errors
%               RELI  -> reliability of factor scores
%
% DEPENDENCIES: pgrad.m
%

function [TH,SE,RELI] = eapgrad (X,LAM,THRES,sigj,nodos, index_nodos);

[n,m] = size(X);

if  (n>m), ni=n; 
else       ni=m; end;

[m,r] = size(LAM);
[nnod,tmp]=size(nodos);
[hnod,r] =size(index_nodos);

L1 = zeros(nnod^r,1);

nume_th=zeros(r,1);
nume_se=zeros(r,1);

TH = zeros(r,1);
SE = zeros(r,1);
RELI = zeros(r,1);

deno =0;
p = zeros (ni,1);

for h=1:hnod,
    
      for j=1:ni,
         
         x=0; 
         for i=1:r,
             x = x + LAM(j,i)*nodos(index_nodos(h,i),1) ;     
         end;
         
        if ((X(j)-1) ~= 0),
           p1 = pgrad (x, THRES(X(j)-1,j),sigj(j));
        end;
         p2 = 1;
         if (THRES(X(j),j) ~= 0),
             p2 = pgrad (x, THRES(X(j),j),sigj(j));
         end;
         if ((X(j)-1) == 0),
            p(j) = p2;
         else
            p(j) = p2 - p1;
         end;
          
      end;

     L1(h,1) = 1;
     for j=1:ni,
         L1(h,1) = L1(h,1) * p(j);
     end;

     pp = 1;
     for i=1:r,
        pp     = pp*nodos(index_nodos(h,i),2);
     end;   
     pp=L1(h,1)*pp;

     deno  = deno  + pp;
     for i=1:r,
         nume_th(i)=nume_th(i) + pp*nodos(index_nodos(h,i),1);
         nume_se(i)=nume_se(i) + pp*nodos(index_nodos(h,i),1)*nodos(index_nodos(h,i),1);
     end;

end;

for i=1:r,
  TH(i,1) = nume_th(i)/ deno;
  SE(i,1) = sqrt(nume_se(i)/deno - (TH(i,1)*TH(i,1)) );
  RELI(i,1) = 1-(nume_se(i)/deno - (TH(i,1)*TH(i,1)) );
end;  
  
return;

