%% MRFAN : MRFA COMPLETE, computes factor structure matrix X
%
% ARGUMENTS   : SIGMA  -> covariance matrix
%               r      -> dimensionality
%               random -> number of random starts
%
% RETURN VALUE: S        -> factor loading matrix
%               SIGMARED -> covariance/correlation matrix with optimal communalities in the diagonal
%               gam      -> optimal communalities
%
% DEPENDENCIES: mrfa.m
%               glb.m
%               ed.m
%               nrm.m
%               tr.m
%
% defaults conv1=1e-6, conv2=1e-5 
%
function [S, SIGMARED,gam] = mrfan(SIGMA, r, random,PA);

if r== 0,
    conv1=0.0000001;
    conv2=0.000001;
else
    if nargin<4
        conv1=0.0001;
        conv2=0.001;
    else
        conv1=0.001;
        conv2=0.01;
    end;
end
    
start=random;
gam=-1;
while gam(1) == -1,
    [gam, f] = mrfa (SIGMA, r, start, conv1, conv2);
end;

SIGMARED=SIGMA-diag(diag(SIGMA))+diag(gam);
[V,L]=ed(SIGMARED);
VV=V(:,1:r);
LL=L(1:r,1:r);
S=VV*sqrt(LL);

return