%% POLYCHORIC : Polychoric Matrix Calculation
%
% ARGUMENTS   : X    -> Binary Matrix  (N x m)
%               Xmin -> Vector containing the minimum value of the variables (m x 1)
%               Xmax -> Vector containing the maximum value of the variables (m x 1)
%
% RETURN VALUE: R     -> Tetrachoric/Polychoric Matrix
%               THRES -> Variable's Thresholds
%               CON   -> Super Matrix containing the contingence tables
%
% DEPENDENCIES: poli.m
%               tetra.m
%               TableConti.m
%               ppnd.m
%               normalbi.m
%               ordnorb.m
%               ordnormalbi.m
%               bivnor.m
%               fnor.m
%
% LAST UPDATED : 17/04/2012
%                Urbano Lorenzo-Seva
%

function [R,THRES,CON]=polychoric(X,Xmin,Xmax);
[N,m] = size(X);
conv = 1E-8;

Ki = (Xmax - Xmin + 1);
Kmax= max(Ki);

R=eye(m);
THRES=zeros(m,max(Ki')-1);

CON = [];

tstart = tic;
tstart2 = tic;
tmp3 = 0; bar2 = waitbar(tmp3,'Dispersion matrix');
total = m*(m-1)/2;

ch=0;

for i=1:(m-1),

   for j=i+1:m,
       
       ch=ch+1;
       
      Xi = [X(:,i),X(:,j)];
       
       TC = tableconti(Xi,[Xmin(i) Xmin(j)],[Xmax(i) Xmax(j)]);
        if min(min(TC)') == 0,
            TC = tableconti(Xi,[Xmin(i) Xmin(j)],[Xmax(i) Xmax(j)])+0.5;
        end;
      
       TCp=[];
       for k=Ki(j):-1:1,
          TCp = [TCp TC(k,:)'];
       end;
       
       TCpp = zeros(Kmax,Kmax);
       for k=1:Ki(i),
          for h=1:Ki(j),
              TCpp(k,h) = TCp(k,h);
          end;
       end;
       CON = [CON; TCpp];

       zero1=min(sum(TC)');
       zero2=min(sum(TC')');
       if (zero1 == 0) | (zero2 == 0),
           buff =sprintf('Sorry, polychoric correlation between variables %.0f and %.0f cannot be computed',i,j);
           disp(buff);
           r=0.0;
           tha=zeros(Ki(i)+1,1);
           thb=zeros(Ki(j)+1,1);
       else,   
         tmp = sum(TC)/sum(sum(TC)');
         tha=zeros(Ki(i)+1,1);
         tha(1)=-100;
         for k=1:Ki(i),
            tmp1= sum(tmp(1:k)');
            tha(k+1)=ppnd(tmp1);
         end;
         tha(Ki(i)+1)=5;
       
         tmp = sum(TC')/sum(sum(TC)');
         thb  = zeros(Ki(j)+1,1);
         thb(1)=-100;
         for k=1:Ki(j)-1,
            tmp1= sum(tmp(1:k)');
            thb(Ki(j)-k+1)= -1*ppnd(tmp1);
         end;
         thb(Ki(j)+1)=5;
       
         if ((Ki(i) == 2) & (Ki(j) == 2)),
%            r = tetra(TC(2,1),TC(1,1),TC(2,2),TC(1,2));
            r = tetra2005(TC(2,1),TC(1,1),TC(2,2),TC(1,2));
            rp=corrcoef(Xi);
            r = r*sign(rp(2,1));
        else,
            r = poli(TC,tha,thb,[Ki(i) Ki(j)],conv);
          
        end;
       end;
       R(i,j) = r;
       R(j,i) = r;
       
       compT = toc(tstart);
       compT = compT*(total-ch)/ch;
       s_tmp=['Dispersion matrix (Remaining time = ' Time2String( compT ) ')'];
       waitbar(ch/(total),bar2,s_tmp);
    end;
    for k=2:Ki(i),
       THRES(i,k-1) = tha(k);
    end;
    
end;

for k=2:Ki(j),
    THRES(m,k-1) = thb(k);
end;
close(bar2);

return;
