%% scores : Get factor scores for each individual
%
% Ten Berge, J.M.F., Krijnen, W., Wansbeek, T., & Shapiro, A. (1999). Some new results on 
% correlation-preserving factor scores prediction methods. Linear Algebra and its Applications, 289, 
% 311-318.
%
% ARGUMENTS   : Y   -> Raw scores
%               P   -> Loading matrix
%               PHI -> Inter-factor correlation matrix
%
% RETURN VALUE: F   -> Factor scores
%               E   -> standard errors of the regression estimates 
%               W   -> regression estimates 
%

function [F,E,W] = scores(Y, P, PHI);

  [n,m] = size(Y);
  [m,r] = size(P);

  M = mean(Y); Sx = std(Y);
  DIF = Y - (ones(n,1) * M);
  Z = DIF ./ (ones(n,1) * Sx);
  
  R = corrcoef(Y);
  
  %%% OBTENCIN DE LOS PESOS
  L = P*PHI^(1/2);
  C = R^(-1/2) * L * (L'*R*L)^(-1/2);
  W = R^(1/2) * C * PHI^(1/2);
  
  %%% ESTIMACION DE LAS PUNTUACIONES FACTORIALES
  F = Z*W;
  
  %%% ESTIMACION DE LAS ERRORES STANDARDS
  U = diag(diag(R - P*PHI*P'));
  
%  VE = (P' * U^(-1) * P)^(-1);
%  VE = (L' * U^(-1) * L )^(-1)*2;
  VE = (P' * U^(-1) * P )^(-1)*2;
  E  = sqrt(diag(VE)) ;

  return;